@@ -1,5 +1,22 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+# Copyright (C) 2008,2009 Sebastian Pölsterl
+#
+# This file is part of GNOME DVB Daemon.
+#
+# GNOME DVB Daemon is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# GNOME DVB Daemon is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
+
 import dbus
 import dbus.glib
 import gobject
@@ -7,11 +24,12 @@ import gst
 import re
 import sys
 
-__all__= [
+__all__ = [
     "global_error_handler",
     "get_adapter_info",
     "get_dvb_devices",
     "DVBManagerClient",
+    "DVBDeviceGroupClient",
     "DVBScannerClient",
     "DVBRecordingsStoreClient",
     "DVBRecorderClient",
@@ -19,17 +37,15 @@ __all__= [
     "DVBScheduleClient",
 ]
 
-service = "org.gnome.DVB"
-manager_iface = "org.gnome.DVB.Manager"
-manager_path = "/org/gnome/DVB/Manager"
-recstore_iface = "org.gnome.DVB.RecordingsStore"
-recstore_path = "/org/gnome/DVB/RecordingsStore"
-recorder_iface = "org.gnome.DVB.Recorder"
-channel_list_iface = "org.gnome.DVB.ChannelList"
-schedule_iface = "org.gnome.DVB.Schedule"
-sat_scanner_iface = "org.gnome.DVB.Scanner.Satellite"
-cable_scanner_iface = "org.gnome.DVB.Scanner.Cable"
-terrestrial_scanner_iface = "org.gnome.DVB.Scanner.Terrestrial"
+SERVICE = "org.gnome.DVB"
+MANAGER_IFACE = "org.gnome.DVB.Manager"
+MANAGER_PATH = "/org/gnome/DVB/Manager"
+DEVICE_GROUP_IFACE = "org.gnome.DVB.DeviceGroup"
+RECSTORE_IFACE = "org.gnome.DVB.RecordingsStore"
+RECSTORE_PATH = "/org/gnome/DVB/RecordingsStore"
+RECORDER_IFACE = "org.gnome.DVB.Recorder"
+CHANNEL_LIST_IFACE = "org.gnome.DVB.ChannelList"
+SCHEDULE_IFACE = "org.gnome.DVB.Schedule"
 
 HAL_MANAGER_IFACE = "org.freedesktop.Hal.Manager"
 HAL_DEVICE_IFACE = "org.freedesktop.Hal.Device"
@@ -61,36 +77,37 @@ def get_adapter_info(adapter):
     pipeline.set_state(gst.STATE_NULL)
     return info
 
-def get_dvb_devices():
+def get_dvb_devices(reply_handler, error_handler):
+    def find_devices_handler(objects):
+        deviceslist = []
+        for o in objects:
+            proxy = bus.get_object(HAL_SERVICE, o)
+            dev = dbus.Interface(proxy, HAL_DEVICE_IFACE)
+
+            dev_file = dev.GetProperty("linux.device_file")
+        
+            match = re.search("adapter(\d+?)/frontend(\d+?)", dev_file)
+            if match != None:
+                adapter = int(match.group(1))
+                info = {}
+                info["adapter"] = adapter
+                info["frontend"] = int(match.group(2))
+                deviceslist.append(info)
+                
+        reply_handler(deviceslist)
+    
     bus = dbus.SystemBus()
     # Get proxy object
     proxy = bus.get_object(HAL_SERVICE, HAL_MANAGER_PATH)
     # Apply the correct interace to the proxy object
     halmanager = dbus.Interface(proxy, HAL_MANAGER_IFACE)
-    objects = halmanager.FindDeviceByCapability("dvb")
-
-    deviceslist = []
-    for o in objects:
-	    proxy = bus.get_object(HAL_SERVICE, o)
-	    dev = dbus.Interface(proxy, HAL_DEVICE_IFACE)
-
-	    dev_file = dev.GetProperty("linux.device_file")
-	
-	    match = re.search("adapter(\d+?)/frontend(\d+?)", dev_file)
-	    if match != None:
-		    adapter = int(match.group(1))
-		    info = {}
-		    info["adapter"] = adapter
-		    info["frontend"] = int(match.group(2))
-		    deviceslist.append(info)
-			
-    return deviceslist
+    objects = halmanager.FindDeviceByCapability("dvb", reply_handler=find_devices_handler, error_handler=error_handler)
 
 class DVBManagerClient(gobject.GObject):
     
     __gsignals__ = {
-        "changed":        (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [int, int]),
-        "group-changed":  (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [int, int, int, int]),
+        "group-added":  (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [int]),
+        "group-removed":  (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [int]),
     }
     
     def __init__(self):
@@ -98,55 +115,107 @@ class DVBManagerClient(gobject.GObject):
     
         bus = dbus.SessionBus()
         # Get proxy object
-        proxy = bus.get_object(service, manager_path)
+        proxy = bus.get_object(SERVICE, MANAGER_PATH)
         # Apply the correct interace to the proxy object
-        self.manager = dbus.Interface(proxy, manager_iface)
-        self.manager.connect_to_signal("Changed", self.on_changed)
-        self.manager.connect_to_signal("GroupChanged", self.on_group_changed)
+        self.manager = dbus.Interface(proxy, MANAGER_IFACE)
+        self.manager.connect_to_signal("GroupAdded", self.on_group_added)
+        self.manager.connect_to_signal("GroupRemoved", self.on_group_removed)
         
     def get_scanner_for_device(self, adapter, frontend):
         objpath, scanner_iface = self.manager.GetScannerForDevice (adapter, frontend)
         return DVBScannerClient(objpath, scanner_iface)
         
-    def get_registered_device_groups(self):
-        return self.manager.GetRegisteredDeviceGroups()
-        
-    def get_recorder(self, group_id):
-        return self.manager.GetRecorder(group_id)
-        
-    def add_device_to_new_group (self, adapter, frontend, channels_file, recordings_dir, name):
-        return self.manager.AddDeviceToNewGroup(adapter, frontend, channels_file, recordings_dir, name)
-        
-    def add_device_to_existing_group (self, adapter, frontend, group_id):
-        return self.manager.AddDeviceToExistingGroup(adapter, frontend, group_id)
-        
-    def remove_device_from_group(self, adapter, frontend, group_id):
-        return self.manager.RemoveDeviceFromGroup(adapter, frontend, group_id)
-        
-    def get_device_group_members(self, group_id):
-        return self.manager.GetDeviceGroupMembers(group_id)
-        
-    def get_device_group_name(self, group_id):
-        return self.manager.GetDeviceGroupName(group_id)
-        
-    def get_type_of_device_group(self, group_id):
-        return self.manager.GetTypeOfDeviceGroup(group_id)
+    def get_device_group(self, group_id):
+        path = self.manager.GetDeviceGroup(group_id)
+        return DVBDeviceGroupClient(path)
         
+    def get_registered_device_groups(self, reply_handler, error_handler):
+        def groups_handler(paths):
+            reply_handler([DVBDeviceGroupClient(path) for path in paths])
+        self.manager.GetRegisteredDeviceGroups(reply_handler=groups_handler, error_handler=error_handler)
+       
+    def add_device_to_new_group (self, adapter, frontend, channels_file, recordings_dir, name, **kwargs):
+        return self.manager.AddDeviceToNewGroup(adapter, frontend, channels_file, recordings_dir, name, **kwargs)
+       
     def get_name_of_registered_device(self, adapter, frontend):
         return self.manager.GetNameOfRegisteredDevice(adapter, frontend)
         
-    def get_schedule(self, group_id, channel_sid):
-        s = DVBScheduleClient(self.manager.GetSchedule(group_id, channel_sid))
-        s._group = group_id
-        s._sid = channel_sid
-        return s
+    def get_device_group_size(self):
+        return self.manager.GetDeviceGroupSize()
+    
+    def on_group_added(self, group_id):
+        self.emit("group-added", group_id)
+ 
+    def on_group_removed(self, group_id):
+        self.emit("group-removed", group_id)
+
+class DVBDeviceGroupClient(gobject.GObject):
+
+    __gsignals__ = {
+        "device-added":  (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [int, int]),
+        "device-removed":  (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [int, int]),
+    }
+    
+    def __init__(self, objpath):
+        gobject.GObject.__init__(self)
         
-    def on_changed(self, group_id, change_type):
-        self.emit("changed", group_id, change_type)
+        elements = objpath.split("/")
         
-    def on_group_changed(self, group_id, adapter, frontend, change_type):
-        self.emit("group-changed", group_id, adapter, frontend, change_type)
+        self._id = int(elements[5])
         
+        bus = dbus.SessionBus()
+        # Get proxy object
+        proxy = bus.get_object(SERVICE, objpath)
+        # Apply the correct interace to the proxy object
+        self.devgroup = dbus.Interface(proxy, DEVICE_GROUP_IFACE)
+        self.devgroup.connect_to_signal("DeviceAdded", self.on_device_added)
+        self.devgroup.connect_to_signal("DeviceRemoved", self.on_device_removed)
+        
+    def get_id(self):
+        return self._id
+         
+    def get_recorder(self):
+        path = self.devgroup.GetRecorder()
+        return DVBRecorderClient(path)
+        
+    def add_device (self, adapter, frontend, **kwargs):
+        return self.devgroup.AddDevice(adapter, frontend, **kwargs)
+        
+    def remove_device(self, adapter, frontend):
+        return self.devgroup.RemoveDevice(adapter, frontend)
+    
+    def get_channel_list(self):
+        path = self.devgroup.GetChannelList()
+        return DVBChannelListClient(path)
+    
+    def get_members(self):
+        return self.devgroup.GetMembers()
+        
+    def get_name(self):
+        return self.devgroup.GetName()
+    
+    def set_name(self, name):
+        return self.devgroup.SetName(name)
+        
+    def get_type(self):
+        return self.devgroup.GetType()
+        
+    def get_schedule(self, channel_sid):
+        path = self.devgroup.GetSchedule(channel_sid)
+        return DVBScheduleClient(path)
+        
+    def get_recordings_directory (self):
+        return self.devgroup.GetRecordingsDirectory()
+        
+    def set_recordings_directory (self, location):
+        return self.devgroup.SetRecordingsDirectory(location)
+     
+    def on_device_added(self, adapter, frontend):
+        self.emit("device-added", adapter, frontend)
+ 
+    def on_device_removed(self, adapter, frontend):
+        self.emit("device-removed", adapter, frontend)
+
 class DVBScannerClient(gobject.GObject):
 
     __gsignals__ = {
@@ -160,7 +229,7 @@ class DVBScannerClient(gobject.GObject):
         gobject.GObject.__init__(self)
         
         bus = dbus.SessionBus()
-        proxy = bus.get_object(service, objpath)
+        proxy = bus.get_object(SERVICE, objpath)
         self.scanner = dbus.Interface(proxy, scanner_iface)
         self.scanner.connect_to_signal ("Finished", self.on_finished)
         self.scanner.connect_to_signal ("FrequencyScanned", self.on_frequency_scanned)
@@ -179,8 +248,11 @@ class DVBScannerClient(gobject.GObject):
     def destroy(self):
         self.scanner.Destroy()
         
-    def write_channels_to_file(self, channelfile):
-        self.scanner.WriteChannelsToFile(channelfile)
+    def write_channels_to_file(self, channel_sids, channelfile, **kwargs):
+        self.scanner.WriteChannelsToFile(channel_sids, channelfile, **kwargs)
+        
+    def write_all_channels_to_file(self, channelfile, **kwargs):
+        self.scanner.WriteAllChannelsToFile(channelfile, **kwargs)
     
     def on_finished(self):
         self.emit("finished")
@@ -205,9 +277,9 @@ class DVBRecordingsStoreClient(gobject.GObject):
         
         bus = dbus.SessionBus()
         # Get proxy object
-        proxy = bus.get_object(service, recstore_path)
+        proxy = bus.get_object(SERVICE, RECSTORE_PATH)
         # Apply the correct interace to the proxy object
-        self.recstore = dbus.Interface(proxy, recstore_iface)
+        self.recstore = dbus.Interface(proxy, RECSTORE_IFACE)
         self.recstore.connect_to_signal ("Changed", self.on_changed)
         
     def get_recordings(self, **kwargs):
@@ -231,8 +303,14 @@ class DVBRecordingsStoreClient(gobject.GObject):
     def get_start_timestamp(self, rid):
         return self.recstore.GetStartTimestamp(rid)
         
-    def delete(self, rid):
-        return self.recstore.Delete(rid)
+    def delete(self, rid, **kwargs):
+        return self.recstore.Delete(rid, **kwargs)
+        
+    def get_channel_name(self, rid):
+        return self.recstore.GetChannelName(rid)
+        
+    def get_all_informations(self, rid):
+        return self.recstore.GetAllInformations(rid)
         
     def on_changed(self, rid, typeid):
         self.emit("changed", rid, typeid)
@@ -245,15 +323,14 @@ class DVBRecorderClient(gobject.GObject):
         "changed": (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [int, int]),
     }
 
-    def __init__(self, group_id):
+    def __init__(self, object_path):
         gobject.GObject.__init__(self)
         
         bus = dbus.SessionBus()
         # Get proxy object
-        object_path = "/org/gnome/DVB/Recorder/%s" % group_id
-        proxy = bus.get_object(service, object_path)
+        proxy = bus.get_object(SERVICE, object_path)
         # Apply the correct interace to the proxy object
-        self.recorder = dbus.Interface(proxy, recorder_iface)
+        self.recorder = dbus.Interface(proxy, RECORDER_IFACE)
         self.recorder.connect_to_signal("RecordingStarted", self.on_recording_started)
         self.recorder.connect_to_signal("RecordingFinished", self.on_recording_finished)
         self.recorder.connect_to_signal("Changed", self.on_changed)
@@ -265,6 +342,9 @@ class DVBRecorderClient(gobject.GObject):
     def add_timer (self, channel, year, month, day, hour, minute, duration):
         return self.recorder.AddTimer(channel, year, month, day, hour, minute, duration)
         
+    def add_timer_with_margin (self, channel, year, month, day, hour, minute, duration):
+        return self.recorder.AddTimerWithMargin(channel, year, month, day, hour, minute, duration)
+        
     def add_timer_for_epg_event(self, event_id, channel_sid):
         return self.recorder.AddTimerForEPGEvent(event_id, channel_sid)
         
@@ -309,13 +389,12 @@ class DVBRecorderClient(gobject.GObject):
            
 class DVBChannelListClient:
 
-    def __init__(self, group_id):
+    def __init__(self, object_path):
         bus = dbus.SessionBus()
         # Get proxy object
-        object_path = "/org/gnome/DVB/ChannelList/%s" % group_id
-        proxy = bus.get_object(service, object_path)
+        proxy = bus.get_object(SERVICE, object_path)
         # Apply the correct interace to the proxy object
-        self.channels = dbus.Interface(proxy, channel_list_iface)
+        self.channels = dbus.Interface(proxy, CHANNEL_LIST_IFACE)
         self.object_path = object_path
         
     def get_path(self):
@@ -342,19 +421,25 @@ class DVBChannelListClient:
     def get_channel_url(self, cid):
         return self.channels.GetChannelURL(cid)
         
+    def get_channel_infos(self, **kwargs):
+        return self.channels.GetChannelInfos(**kwargs)
+        
 class DVBScheduleClient(gobject.GObject):
 
     def __init__(self, object_path):
         gobject.GObject.__init__(self)
         
-        self._group = 0
-        self._sid = 0
+        # "/org/gnome/DVB/DeviceGroup/%u/Schedule/%u";
+        elements = object_path.split("/")
+        
+        self._group = int(elements[5])
+        self._sid = int(elements[7])
         
         bus = dbus.SessionBus()
         # Get proxy object
-        proxy = bus.get_object(service, object_path)
+        proxy = bus.get_object(SERVICE, object_path)
         # Apply the correct interace to the proxy object
-        self.schedule = dbus.Interface(proxy, schedule_iface)
+        self.schedule = dbus.Interface(proxy, SCHEDULE_IFACE)
         
     def get_group_id(self):
         return self._group
@@ -365,6 +450,12 @@ class DVBScheduleClient(gobject.GObject):
     def get_all_events(self, **kwargs):
         return self.schedule.GetAllEvents(**kwargs)
         
+    def get_all_event_infos(self, **kwargs):
+        return self.schedule.GetAllEventInfos(**kwargs)
+        
+    def get_informations(self, eid, **kwargs):
+        return self.schedule.GetInformations(eid, **kwargs)
+        
     def now_playing(self):
         return self.schedule.NowPlaying()
         
@@ -386,6 +477,9 @@ class DVBScheduleClient(gobject.GObject):
     def get_local_start_time(self, eid):
         return self.schedule.GetLocalStartTime(eid)
         
+    def get_local_start_timestamp(self, eid):
+        return self.schedule.GetLocalStartTimestamp(eid)
+        
     def is_running(self, eid):
         return self.schedule.IsRunning(eid)
         
@@ -411,54 +505,56 @@ if __name__ == '__main__':
     #scanner.add_scanning_data(pro7_sat)
     #scanner.run()
     
-    dev_groups = manager.get_registered_device_groups()
-    
-    for group_id in dev_groups:
-        print "Members", manager.get_device_group_members(group_id)
-    
-        rec = DVBRecorderClient(group_id)
-        timers = rec.get_timers()
-        print timers
-        for tid in timers:
-            print "Start", rec.get_start_time(tid)
-            print "End", rec.get_end_time(tid)
-            print "Duration", rec.get_duration(tid)
-            
-        print rec.get_active_timers()
+    def device_handler(dev_groups):
+        for dev_group in dev_groups:
+            print "Members", dev_group.get_members()
         
-        print rec.add_timer(32, 2008, 7, 28, 23, 42, 2)
+            rec = dev_group.get_recorder()
+            timers = rec.get_timers()
+            print timers
+            for tid in timers:
+                print "Start", rec.get_start_time(tid)
+                print "End", rec.get_end_time(tid)
+                print "Duration", rec.get_duration(tid)
+                
+            print rec.get_active_timers()
             
-        channellist = DVBChannelListClient(group_id)
-        print "RADIO CHANNELS"
-        for channel_id in channellist.get_radio_channels():
-            print "SID", channel_id
-            print "Name", channellist.get_channel_name(channel_id)
-            print "Network", channellist.get_channel_network(channel_id)
-        print
-        print "TV CHANNELS"
-        for channel_id in channellist.get_tv_channels():
-            print "SID", channel_id
-            print "Name", channellist.get_channel_name(channel_id)
-            print "Network", channellist.get_channel_network(channel_id)
-            print "URL", channellist.get_channel_url(channel_id)
-            schedule = manager.get_schedule (group_id, channel_id)
-            event_now = schedule.now_playing()
-            print u"Now: %s" % schedule.get_name(event_now)
-            print u"\tDesc: %s" % schedule.get_short_description(event_now)
-            time = schedule.get_local_start_time(event_now)
-            if len(time) == 6:
-                print u"\tStart: %04d-%02d-%02d %02d:%02d:%02d" % (time[0], time[1], time[2], time[3],
-                    time[4], time[5])
-            print u"\tDuration: %s" % schedule.get_duration(event_now)
+            print rec.add_timer(32, 2008, 7, 28, 23, 42, 2)
+                
+            channellist = dev_group.get_channel_list()
+            print "RADIO CHANNELS"
+            for channel_id in channellist.get_radio_channels():
+                print "SID", channel_id
+                print "Name", channellist.get_channel_name(channel_id)
+                print "Network", channellist.get_channel_network(channel_id)
             print
-        
-    recstore = DVBRecordingsStoreClient()
-    for rid in recstore.get_recordings():
-        print "Location", recstore.get_location(rid)
-        print "Start", recstore.get_start_time(rid)
-        print recstore.get_start_timestamp(rid)
-        print "Length", recstore.get_length(rid)    
-        print "Name", recstore.get_name (rid)
-        print "Desc", recstore.get_description(rid)
+            print "TV CHANNELS"
+            for channel_id in channellist.get_tv_channels():
+                print "SID", channel_id
+                print "Name", channellist.get_channel_name(channel_id)
+                print "Network", channellist.get_channel_network(channel_id)
+                print "URL", channellist.get_channel_url(channel_id)
+                schedule = dev_group.get_schedule (channel_id)
+                event_now = schedule.now_playing()
+                print u"Now: %s" % schedule.get_name(event_now)
+                print u"\tDesc: %s" % schedule.get_short_description(event_now)
+                time = schedule.get_local_start_time(event_now)
+                if len(time) == 6:
+                    print u"\tStart: %04d-%02d-%02d %02d:%02d:%02d" % (time[0], time[1], time[2], time[3],
+                        time[4], time[5])
+                print u"\tDuration: %s" % schedule.get_duration(event_now)
+                print
+            
+        recstore = DVBRecordingsStoreClient()
+        for rid in recstore.get_recordings():
+            print "Channel", recstore.get_channel_name(rid)
+            print "Location", recstore.get_location(rid)
+            print "Start", recstore.get_start_time(rid)
+            print recstore.get_start_timestamp(rid)
+            print "Length", recstore.get_length(rid)    
+            print "Name", recstore.get_name (rid)
+            print "Desc", recstore.get_description(rid)
+    
+    dev_groups = manager.get_registered_device_groups(reply_handler=device_handler)
     
     loop.run()
