@@ -37,7 +37,7 @@ class EditTimersDialog(gtk.Dialog):
         @param parent: Parent window
         @type parent: gtk.Window
         """
-        gtk.Dialog.__init__(self, title=_("Timers"),
+        gtk.Dialog.__init__(self, title=_("Recording schedule"),
             parent=parent,
             flags=gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
             buttons=(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE))
@@ -54,24 +54,13 @@ class EditTimersDialog(gtk.Dialog):
         self.timersview = gtk.TreeView(self.timerslist)
         self.timersview.get_selection().connect("changed",
             self._on_timers_selection_changed)
-        
-        cell_rec = gtk.CellRendererPixbuf()
-        col_rec = gtk.TreeViewColumn()
-        col_rec.pack_start(cell_rec)
-        col_rec.set_cell_data_func(cell_rec, self._get_recording_icon_for_cell)
-        col_rec.add_attribute(cell_rec, "stock-id", self.COL_ACTIVE)
-        
-        self.timersview.append_column(col_rec)
-         
-        cell_id = gtk.CellRendererText()
-        col_id = gtk.TreeViewColumn(_("ID"))
-        col_id.pack_start(cell_id)
-        col_id.add_attribute(cell_id, "text", self.COL_ID)
-        
-        self.timersview.append_column(col_id)
-        
-        cell_channel = gtk.CellRendererText()
+
         col_channel = gtk.TreeViewColumn(_("Channel"))
+        cell_rec = gtk.CellRendererPixbuf()
+        col_channel.pack_start(cell_rec)
+        col_channel.set_cell_data_func(cell_rec, self._get_recording_icon_for_cell)
+        col_channel.add_attribute(cell_rec, "stock-id", self.COL_ACTIVE)
+        cell_channel = gtk.CellRendererText()
         col_channel.pack_start(cell_channel)
         col_channel.add_attribute(cell_channel, "text", self.COL_CHANNEL)
         
@@ -87,7 +76,7 @@ class EditTimersDialog(gtk.Dialog):
         cell_duration = gtk.CellRendererText()
         col_duration = gtk.TreeViewColumn(_("Duration"))
         col_duration.pack_start(cell_duration)
-        col_duration.add_attribute(cell_duration, "text", self.COL_DURATION )
+        col_duration.set_cell_data_func(cell_duration, self._get_duration_data)
         
         self.timersview.append_column(col_duration)
         
@@ -113,8 +102,8 @@ class EditTimersDialog(gtk.Dialog):
         
         self.show_all()
         
-    def set_recorder(self, group_id):
-        self.recorder = gnomedvb.DVBRecorderClient(group_id)
+    def set_recorder(self, dev_group):
+        self.recorder = dev_group.get_recorder()
         self.recorder.connect("changed", self._on_recorder_changed)
         self.recorder.connect("recording-started", self._set_recording_state, True)
         self.recorder.connect("recording-finished", self._set_recording_state, False)
@@ -169,12 +158,7 @@ class EditTimersDialog(gtk.Dialog):
         d = TimerDialog(self, self.device_group)
         d.run()
         d.destroy()
-     
-    def _on_recorderscombo_changed(self, combo):
-        self.timerslist.clear()
-        self.get_timers(self._get_active_device_group())
-        self.button_add.set_sensitive(True)
-        
+   
     def _on_recorder_changed(self, recorder, timer_id, typeid):
         if recorder == self.recorder:
             if (typeid == 0):
@@ -203,4 +187,10 @@ class EditTimersDialog(gtk.Dialog):
     def _get_recording_icon_for_cell(self, column, cell, model, aiter):
         if model[aiter][self.COL_ACTIVE]:
             cell.set_property("stock-id", gtk.STOCK_MEDIA_RECORD)
-    
+            
+    def _get_duration_data(self, column, cell, model, aiter):
+        # We have minutes but need seconds
+        duration = model[aiter][self.COL_DURATION] * 60
+        duration_str = gnomedvb.seconds_to_time_duration_string(duration)
+        cell.set_property("text", duration_str)
+
