@@ -17,36 +17,216 @@
  * along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <src/Event.h>
-#include "src/Utils.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
+#include <time.h>
 #include <gobject/gvaluecollector.h>
 
 
+#define DVB_TYPE_EVENT (dvb_event_get_type ())
+#define DVB_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_EVENT, DVBEvent))
+#define DVB_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_EVENT, DVBEventClass))
+#define DVB_IS_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_EVENT))
+#define DVB_IS_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_EVENT))
+#define DVB_EVENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_EVENT, DVBEventClass))
+
+typedef struct _DVBEvent DVBEvent;
+typedef struct _DVBEventClass DVBEventClass;
+typedef struct _DVBEventPrivate DVBEventPrivate;
+
+#define DVB_EVENT_TYPE_AUDIO_COMPONENT (dvb_event_audio_component_get_type ())
+#define DVB_EVENT_AUDIO_COMPONENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_EVENT_TYPE_AUDIO_COMPONENT, DVBEventAudioComponent))
+#define DVB_EVENT_AUDIO_COMPONENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_EVENT_TYPE_AUDIO_COMPONENT, DVBEventAudioComponentClass))
+#define DVB_EVENT_IS_AUDIO_COMPONENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_EVENT_TYPE_AUDIO_COMPONENT))
+#define DVB_EVENT_IS_AUDIO_COMPONENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_EVENT_TYPE_AUDIO_COMPONENT))
+#define DVB_EVENT_AUDIO_COMPONENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_EVENT_TYPE_AUDIO_COMPONENT, DVBEventAudioComponentClass))
+
+typedef struct _DVBEventAudioComponent DVBEventAudioComponent;
+typedef struct _DVBEventAudioComponentClass DVBEventAudioComponentClass;
+
+#define DVB_EVENT_TYPE_VIDEO_COMPONENT (dvb_event_video_component_get_type ())
+#define DVB_EVENT_VIDEO_COMPONENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_EVENT_TYPE_VIDEO_COMPONENT, DVBEventVideoComponent))
+#define DVB_EVENT_VIDEO_COMPONENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_EVENT_TYPE_VIDEO_COMPONENT, DVBEventVideoComponentClass))
+#define DVB_EVENT_IS_VIDEO_COMPONENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_EVENT_TYPE_VIDEO_COMPONENT))
+#define DVB_EVENT_IS_VIDEO_COMPONENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_EVENT_TYPE_VIDEO_COMPONENT))
+#define DVB_EVENT_VIDEO_COMPONENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_EVENT_TYPE_VIDEO_COMPONENT, DVBEventVideoComponentClass))
+
+typedef struct _DVBEventVideoComponent DVBEventVideoComponent;
+typedef struct _DVBEventVideoComponentClass DVBEventVideoComponentClass;
+
+#define DVB_EVENT_TYPE_TELETEXT_COMPONENT (dvb_event_teletext_component_get_type ())
+#define DVB_EVENT_TELETEXT_COMPONENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_EVENT_TYPE_TELETEXT_COMPONENT, DVBEventTeletextComponent))
+#define DVB_EVENT_TELETEXT_COMPONENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_EVENT_TYPE_TELETEXT_COMPONENT, DVBEventTeletextComponentClass))
+#define DVB_EVENT_IS_TELETEXT_COMPONENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_EVENT_TYPE_TELETEXT_COMPONENT))
+#define DVB_EVENT_IS_TELETEXT_COMPONENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_EVENT_TYPE_TELETEXT_COMPONENT))
+#define DVB_EVENT_TELETEXT_COMPONENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_EVENT_TYPE_TELETEXT_COMPONENT, DVBEventTeletextComponentClass))
+
+typedef struct _DVBEventTeletextComponent DVBEventTeletextComponent;
+typedef struct _DVBEventTeletextComponentClass DVBEventTeletextComponentClass;
+typedef struct _DVBEventAudioComponentPrivate DVBEventAudioComponentPrivate;
+typedef struct _DVBEventParamSpecAudioComponent DVBEventParamSpecAudioComponent;
+typedef struct _DVBEventVideoComponentPrivate DVBEventVideoComponentPrivate;
+typedef struct _DVBEventParamSpecVideoComponent DVBEventParamSpecVideoComponent;
+typedef struct _DVBEventTeletextComponentPrivate DVBEventTeletextComponentPrivate;
+typedef struct _DVBEventParamSpecTeletextComponent DVBEventParamSpecTeletextComponent;
+typedef struct _DVBParamSpecEvent DVBParamSpecEvent;
+
+/**
+     * Represents an EPG event (i.e. a show with all its information)
+     */
+struct _DVBEvent {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	DVBEventPrivate * priv;
+	guint id;
+	guint year;
+	guint month;
+	guint hour;
+	guint day;
+	guint minute;
+	guint second;
+	guint duration;
+	guint running_status;
+	gboolean free_ca_mode;
+	char* name;
+	char* description;
+	char* extended_description;
+	GSList* audio_components;
+	GSList* video_components;
+	GSList* teletext_components;
+};
+
+struct _DVBEventClass {
+	GTypeClass parent_class;
+	void (*finalize) (DVBEvent *self);
+};
+
+struct _DVBEventAudioComponent {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	DVBEventAudioComponentPrivate * priv;
+	char* type;
+};
+
+struct _DVBEventAudioComponentClass {
+	GTypeClass parent_class;
+	void (*finalize) (DVBEventAudioComponent *self);
+};
+
+struct _DVBEventParamSpecAudioComponent {
+	GParamSpec parent_instance;
+};
+
+struct _DVBEventVideoComponent {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	DVBEventVideoComponentPrivate * priv;
+	gboolean high_definition;
+	char* aspect_ratio;
+	gint frequency;
+};
+
+struct _DVBEventVideoComponentClass {
+	GTypeClass parent_class;
+	void (*finalize) (DVBEventVideoComponent *self);
+};
+
+struct _DVBEventParamSpecVideoComponent {
+	GParamSpec parent_instance;
+};
+
+struct _DVBEventTeletextComponent {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	DVBEventTeletextComponentPrivate * priv;
+	char* type;
+};
+
+struct _DVBEventTeletextComponentClass {
+	GTypeClass parent_class;
+	void (*finalize) (DVBEventTeletextComponent *self);
+};
+
+struct _DVBEventParamSpecTeletextComponent {
+	GParamSpec parent_instance;
+};
+
+struct _DVBParamSpecEvent {
+	GParamSpec parent_instance;
+};
 
 
+static gpointer dvb_event_audio_component_parent_class = NULL;
+static gpointer dvb_event_video_component_parent_class = NULL;
+static gpointer dvb_event_teletext_component_parent_class = NULL;
+static gpointer dvb_event_parent_class = NULL;
+
+gpointer dvb_event_ref (gpointer instance);
+void dvb_event_unref (gpointer instance);
+GParamSpec* dvb_param_spec_event (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void dvb_value_set_event (GValue* value, gpointer v_object);
+gpointer dvb_value_get_event (const GValue* value);
+GType dvb_event_get_type (void);
+gpointer dvb_event_audio_component_ref (gpointer instance);
+void dvb_event_audio_component_unref (gpointer instance);
+GParamSpec* dvb_event_param_spec_audio_component (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void dvb_event_value_set_audio_component (GValue* value, gpointer v_object);
+gpointer dvb_event_value_get_audio_component (const GValue* value);
+GType dvb_event_audio_component_get_type (void);
+gpointer dvb_event_video_component_ref (gpointer instance);
+void dvb_event_video_component_unref (gpointer instance);
+GParamSpec* dvb_event_param_spec_video_component (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void dvb_event_value_set_video_component (GValue* value, gpointer v_object);
+gpointer dvb_event_value_get_video_component (const GValue* value);
+GType dvb_event_video_component_get_type (void);
+gpointer dvb_event_teletext_component_ref (gpointer instance);
+void dvb_event_teletext_component_unref (gpointer instance);
+GParamSpec* dvb_event_param_spec_teletext_component (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void dvb_event_value_set_teletext_component (GValue* value, gpointer v_object);
+gpointer dvb_event_value_get_teletext_component (const GValue* value);
+GType dvb_event_teletext_component_get_type (void);
 enum  {
 	DVB_EVENT_DUMMY_PROPERTY
 };
 static void _g_slist_free_dvb_event_audio_component_unref (GSList* self);
 static void _g_slist_free_dvb_event_video_component_unref (GSList* self);
 static void _g_slist_free_dvb_event_teletext_component_unref (GSList* self);
+#define DVB_EVENT_RUNNING_STATUS_UNDEFINED ((guint) 0)
+#define DVB_EVENT_RUNNING_STATUS_NOT_RUNNING ((guint) 1)
+#define DVB_EVENT_RUNNING_STATUS_STARTS_SOON ((guint) 2)
+#define DVB_EVENT_RUNNING_STATUS_PAUSING ((guint) 3)
+#define DVB_EVENT_RUNNING_STATUS_RUNNING ((guint) 4)
+DVBEvent* dvb_event_new (void);
+DVBEvent* dvb_event_construct (GType object_type);
 static gint64 dvb_event_get_end_timestamp (DVBEvent* self);
+gboolean dvb_event_has_expired (DVBEvent* self);
+struct tm dvb_event_get_utc_start_time (DVBEvent* self);
+gboolean dvb_event_is_running (DVBEvent* self);
+char* dvb_event_to_string (DVBEvent* self);
+struct tm dvb_event_get_local_start_time (DVBEvent* self);
+struct tm dvb_utils_create_utc_time (gint year, gint month, gint day, gint hour, gint minute, gint second);
+gint dvb_event_compare (DVBEvent* event1, DVBEvent* event2);
+gboolean dvb_event_equal (DVBEvent* event1, DVBEvent* event2);
 enum  {
 	DVB_EVENT_AUDIO_COMPONENT_DUMMY_PROPERTY
 };
-static gpointer dvb_event_audio_component_parent_class = NULL;
+DVBEventAudioComponent* dvb_event_audio_component_new (void);
+DVBEventAudioComponent* dvb_event_audio_component_construct (GType object_type);
 static void dvb_event_audio_component_finalize (DVBEventAudioComponent* obj);
 enum  {
 	DVB_EVENT_VIDEO_COMPONENT_DUMMY_PROPERTY
 };
-static gpointer dvb_event_video_component_parent_class = NULL;
+DVBEventVideoComponent* dvb_event_video_component_new (void);
+DVBEventVideoComponent* dvb_event_video_component_construct (GType object_type);
 static void dvb_event_video_component_finalize (DVBEventVideoComponent* obj);
 enum  {
 	DVB_EVENT_TELETEXT_COMPONENT_DUMMY_PROPERTY
 };
-static gpointer dvb_event_teletext_component_parent_class = NULL;
+DVBEventTeletextComponent* dvb_event_teletext_component_new (void);
+DVBEventTeletextComponent* dvb_event_teletext_component_construct (GType object_type);
 static void dvb_event_teletext_component_finalize (DVBEventTeletextComponent* obj);
-static gpointer dvb_event_parent_class = NULL;
 static void dvb_event_finalize (DVBEvent* obj);
 
 
@@ -71,16 +251,16 @@ static void _g_slist_free_dvb_event_teletext_component_unref (GSList* self) {
 
 DVBEvent* dvb_event_construct (GType object_type) {
 	DVBEvent* self;
-	GSList* _tmp0;
-	GSList* _tmp1;
-	GSList* _tmp2;
+	GSList* _tmp0_;
+	GSList* _tmp1_;
+	GSList* _tmp2_;
 	self = (DVBEvent*) g_type_create_instance (object_type);
-	_tmp0 = NULL;
-	self->audio_components = (_tmp0 = NULL, (self->audio_components == NULL) ? NULL : (self->audio_components = (_g_slist_free_dvb_event_audio_component_unref (self->audio_components), NULL)), _tmp0);
-	_tmp1 = NULL;
-	self->video_components = (_tmp1 = NULL, (self->video_components == NULL) ? NULL : (self->video_components = (_g_slist_free_dvb_event_video_component_unref (self->video_components), NULL)), _tmp1);
-	_tmp2 = NULL;
-	self->teletext_components = (_tmp2 = NULL, (self->teletext_components == NULL) ? NULL : (self->teletext_components = (_g_slist_free_dvb_event_teletext_component_unref (self->teletext_components), NULL)), _tmp2);
+	_tmp0_ = NULL;
+	self->audio_components = (_tmp0_ = NULL, (self->audio_components == NULL) ? NULL : (self->audio_components = (_g_slist_free_dvb_event_audio_component_unref (self->audio_components), NULL)), _tmp0_);
+	_tmp1_ = NULL;
+	self->video_components = (_tmp1_ = NULL, (self->video_components == NULL) ? NULL : (self->video_components = (_g_slist_free_dvb_event_video_component_unref (self->video_components), NULL)), _tmp1_);
+	_tmp2_ = NULL;
+	self->teletext_components = (_tmp2_ = NULL, (self->teletext_components == NULL) ? NULL : (self->teletext_components = (_g_slist_free_dvb_event_teletext_component_unref (self->teletext_components), NULL)), _tmp2_);
 	self->year = (guint) 0;
 	self->month = (guint) 0;
 	self->hour = (guint) 0;
@@ -102,90 +282,112 @@ DVBEvent* dvb_event_new (void) {
          * Whether the event has started and ended in the past
          */
 gboolean dvb_event_has_expired (DVBEvent* self) {
-	time_t _tmp2 = {0};
-	time_t _tmp0 = {0};
-	struct tm _tmp1 = {0};
+	gboolean result;
+	time_t _tmp2_ = {0};
+	time_t _tmp0_ = {0};
+	struct tm _tmp1_ = {0};
 	struct tm current_utc;
 	gint64 current_time;
 	gint64 end_timestamp;
 	g_return_val_if_fail (self != NULL, FALSE);
-	current_utc = (gmtime_r ((_tmp2 = (time (&_tmp0), _tmp0), &_tmp2), &_tmp1), _tmp1);
+	current_utc = (gmtime_r ((_tmp2_ = (time (&_tmp0_), _tmp0_), &_tmp2_), &_tmp1_), _tmp1_);
 	/* set day light saving time to undefined
 	 otherwise mktime will add an hour,
 	 because it respects dst*/
 	current_utc.tm_isdst = -1;
 	current_time = (gint64) mktime (&current_utc);
 	end_timestamp = dvb_event_get_end_timestamp (self);
-	return end_timestamp < current_time;
+	result = end_timestamp < current_time;
+	return result;
 }
 
 
 gboolean dvb_event_is_running (DVBEvent* self) {
-	time_t _tmp2 = {0};
-	time_t _tmp0 = {0};
-	struct tm _tmp1 = {0};
+	gboolean result;
+	time_t _tmp2_ = {0};
+	time_t _tmp0_ = {0};
+	struct tm _tmp1_ = {0};
 	struct tm time_now;
 	struct tm time_start;
 	gint64 timestamp_now;
 	gint64 timestamp_start;
 	g_return_val_if_fail (self != NULL, FALSE);
-	time_now = (gmtime_r ((_tmp2 = (time (&_tmp0), _tmp0), &_tmp2), &_tmp1), _tmp1);
+	time_now = (gmtime_r ((_tmp2_ = (time (&_tmp0_), _tmp0_), &_tmp2_), &_tmp1_), _tmp1_);
 	time_start = dvb_event_get_utc_start_time (self);
 	timestamp_now = (gint64) timegm (&time_now);
 	timestamp_start = (gint64) timegm (&time_start);
 	if ((timestamp_now - timestamp_start) >= 0) {
 		/* Has started, check if it's still running*/
-		return !dvb_event_has_expired (self);
+		result = !dvb_event_has_expired (self);
+		return result;
 	} else {
 		/* Has not started, yet*/
-		return FALSE;
+		result = FALSE;
+		return result;
 	}
 }
 
 
 char* dvb_event_to_string (DVBEvent* self) {
-	char* _tmp1;
-	char* _tmp0;
-	char* _tmp2;
+	char* result;
+	char* _tmp1_;
+	char* _tmp0_;
+	char* _tmp2_;
 	char* text;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	_tmp2 = NULL;
-	text = (_tmp2 = g_strconcat (_tmp0 = g_strdup_printf ("ID: %u\nDate: %04u-%02u-%02u %02u:%02u:%02u\n", self->id, self->year, self->month, self->day, self->hour, self->minute, self->second), _tmp1 = g_strdup_printf ("Duration: %u\nName: %s\nDescription: %s\n", self->duration, self->name, self->description), NULL), _tmp1 = (g_free (_tmp1), NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	_tmp2_ = NULL;
+	text = (_tmp2_ = g_strconcat (_tmp0_ = g_strdup_printf ("ID: %u\nDate: %04u-%02u-%02u %02u:%02u:%02u\n", self->id, self->year, self->month, self->day, self->hour, self->minute, self->second), _tmp1_ = g_strdup_printf ("Duration: %u\nName: %s\nDescription: %s\n", self->duration, self->name, self->description), NULL), _tmp1_ = (g_free (_tmp1_), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp2_);
 	{
 		gint i;
 		i = 0;
-		for (; i < g_slist_length (self->audio_components); i++) {
-			char* _tmp4;
-			char* _tmp3;
-			_tmp4 = NULL;
-			_tmp3 = NULL;
-			text = (_tmp4 = g_strconcat (text, _tmp3 = g_strdup_printf ("%s ", ((DVBEventAudioComponent*) g_slist_nth_data (self->audio_components, (guint) i))->type), NULL), text = (g_free (text), NULL), _tmp4);
-			_tmp3 = (g_free (_tmp3), NULL);
+		{
+			gboolean _tmp3_;
+			_tmp3_ = TRUE;
+			while (TRUE) {
+				char* _tmp5_;
+				char* _tmp4_;
+				if (!_tmp3_) {
+					i++;
+				}
+				_tmp3_ = FALSE;
+				if (!(i < g_slist_length (self->audio_components))) {
+					break;
+				}
+				_tmp5_ = NULL;
+				_tmp4_ = NULL;
+				text = (_tmp5_ = g_strconcat (text, _tmp4_ = g_strdup_printf ("%s ", ((DVBEventAudioComponent*) g_slist_nth_data (self->audio_components, (guint) i))->type), NULL), text = (g_free (text), NULL), _tmp5_);
+				_tmp4_ = (g_free (_tmp4_), NULL);
+			}
 		}
 	}
-	return text;
+	result = text;
+	return result;
 }
 
 
 struct tm dvb_event_get_local_start_time (DVBEvent* self) {
+	struct tm result;
 	struct tm utc_time;
 	time_t utc_timestamp;
-	struct tm _tmp0 = {0};
+	struct tm _tmp0_ = {0};
 	struct tm local_time;
 	/* Initialize time zone and set values*/
 	utc_time = dvb_event_get_utc_start_time (self);
 	utc_timestamp = timegm (&utc_time);
-	local_time = (localtime_r (&utc_timestamp, &_tmp0), _tmp0);
-	return local_time;
+	local_time = (localtime_r (&utc_timestamp, &_tmp0_), _tmp0_);
+	result = local_time;
+	return result;
 }
 
 
 struct tm dvb_event_get_utc_start_time (DVBEvent* self) {
+	struct tm result;
 	struct tm utc_time;
 	utc_time = dvb_utils_create_utc_time ((gint) self->year, (gint) self->month, (gint) self->day, (gint) self->hour, (gint) self->minute, (gint) self->second);
-	return utc_time;
+	result = utc_time;
+	return result;
 }
 
 
@@ -193,6 +395,7 @@ struct tm dvb_event_get_utc_start_time (DVBEvent* self) {
          * @returns: UNIX time stamp
          */
 static gint64 dvb_event_get_end_timestamp (DVBEvent* self) {
+	gint64 result;
 	struct tm end_time;
 	gint64 before;
 	gint64 after;
@@ -202,7 +405,8 @@ static gint64 dvb_event_get_end_timestamp (DVBEvent* self) {
 	end_time.tm_sec = end_time.tm_sec + ((gint) self->duration);
 	after = (gint64) mktime (&end_time);
 	g_assert ((after - before) == self->duration);
-	return after;
+	result = after;
+	return result;
 }
 
 
@@ -213,49 +417,56 @@ static gint64 dvb_event_get_end_timestamp (DVBEvent* self) {
          * Compare the starting time of two events
          */
 gint dvb_event_compare (DVBEvent* event1, DVBEvent* event2) {
-	gboolean _tmp0;
+	gint result;
+	gboolean _tmp0_;
 	gint64 event1_time;
 	gint64 event2_time;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (event1 == NULL) {
-		_tmp0 = event2 == NULL;
+		_tmp0_ = event2 == NULL;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	if (_tmp0) {
-		return 0;
+	if (_tmp0_) {
+		result = 0;
+		return result;
 	} else {
-		gboolean _tmp2;
-		_tmp2 = FALSE;
+		gboolean _tmp1_;
+		_tmp1_ = FALSE;
 		if (event1 == NULL) {
-			_tmp2 = event2 != NULL;
+			_tmp1_ = event2 != NULL;
 		} else {
-			_tmp2 = FALSE;
+			_tmp1_ = FALSE;
 		}
-		if (_tmp2) {
-			return +1;
+		if (_tmp1_) {
+			result = +1;
+			return result;
 		} else {
-			gboolean _tmp4;
-			_tmp4 = FALSE;
+			gboolean _tmp2_;
+			_tmp2_ = FALSE;
 			if (event1 != NULL) {
-				_tmp4 = event2 == NULL;
+				_tmp2_ = event2 == NULL;
 			} else {
-				_tmp4 = FALSE;
+				_tmp2_ = FALSE;
 			}
-			if (_tmp4) {
-				return -1;
+			if (_tmp2_) {
+				result = -1;
+				return result;
 			}
 		}
 	}
 	event1_time = dvb_event_get_end_timestamp (event1);
 	event2_time = dvb_event_get_end_timestamp (event2);
 	if (event1_time < event2_time) {
-		return -1;
+		result = -1;
+		return result;
 	} else {
 		if (event1_time > event2_time) {
-			return +1;
+			result = +1;
+			return result;
 		} else {
-			return 0;
+			result = 0;
+			return result;
 		}
 	}
 }
@@ -268,17 +479,20 @@ gint dvb_event_compare (DVBEvent* event1, DVBEvent* event2) {
          * event1 and event2 must be part of the same transport stream
          */
 gboolean dvb_event_equal (DVBEvent* event1, DVBEvent* event2) {
-	gboolean _tmp0;
-	_tmp0 = FALSE;
+	gboolean result;
+	gboolean _tmp0_;
+	_tmp0_ = FALSE;
 	if (event1 == NULL) {
-		_tmp0 = TRUE;
+		_tmp0_ = TRUE;
 	} else {
-		_tmp0 = event2 == NULL;
+		_tmp0_ = event2 == NULL;
 	}
-	if (_tmp0) {
-		return FALSE;
+	if (_tmp0_) {
+		result = FALSE;
+		return result;
 	}
-	return event1->id == event2->id;
+	result = event1->id == event2->id;
+	return result;
 }
 
 
