@@ -17,11 +17,99 @@
  * along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <src/MpegTsEnums.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
 
 
+#define DVB_TYPE_DVB_SRC_CODE_RATE (dvb_dvb_src_code_rate_get_type ())
+
+#define DVB_TYPE_DVB_SRC_MODULATION (dvb_dvb_src_modulation_get_type ())
+
+#define DVB_TYPE_DVB_SRC_TRANSMISSION_MODE (dvb_dvb_src_transmission_mode_get_type ())
+
+#define DVB_TYPE_DVB_SRC_BANDWIDTH (dvb_dvb_src_bandwidth_get_type ())
+
+#define DVB_TYPE_DVB_SRC_GUARD (dvb_dvb_src_guard_get_type ())
+
+#define DVB_TYPE_DVB_SRC_HIERARCHY (dvb_dvb_src_hierarchy_get_type ())
+
+#define DVB_TYPE_DVB_SRC_INVERSION (dvb_dvb_src_inversion_get_type ())
+
+typedef enum  {
+	DVB_DVB_SRC_CODE_RATE_FEC_NONE,
+	DVB_DVB_SRC_CODE_RATE_FEC_1_2,
+	DVB_DVB_SRC_CODE_RATE_FEC_2_3,
+	DVB_DVB_SRC_CODE_RATE_FEC_3_4,
+	DVB_DVB_SRC_CODE_RATE_FEC_4_5,
+	DVB_DVB_SRC_CODE_RATE_FEC_5_6,
+	DVB_DVB_SRC_CODE_RATE_FEC_6_7,
+	DVB_DVB_SRC_CODE_RATE_FEC_7_8,
+	DVB_DVB_SRC_CODE_RATE_FEC_8_9,
+	DVB_DVB_SRC_CODE_RATE_FEC_AUTO
+} DVBDvbSrcCodeRate;
+
+typedef enum  {
+	DVB_DVB_SRC_MODULATION_QPSK,
+	DVB_DVB_SRC_MODULATION_QAM_16,
+	DVB_DVB_SRC_MODULATION_QAM_32,
+	DVB_DVB_SRC_MODULATION_QAM_64,
+	DVB_DVB_SRC_MODULATION_QAM_128,
+	DVB_DVB_SRC_MODULATION_QAM_256,
+	DVB_DVB_SRC_MODULATION_QAM_AUTO
+} DVBDvbSrcModulation;
+
+typedef enum  {
+	DVB_DVB_SRC_TRANSMISSION_MODE_TRANSMISSION_MODE_2K,
+	DVB_DVB_SRC_TRANSMISSION_MODE_TRANSMISSION_MODE_8K,
+	DVB_DVB_SRC_TRANSMISSION_MODE_TRANSMISSION_MODE_AUTO
+} DVBDvbSrcTransmissionMode;
+
+typedef enum  {
+	DVB_DVB_SRC_BANDWIDTH_BANDWIDTH_8_MHZ,
+	DVB_DVB_SRC_BANDWIDTH_BANDWIDTH_7_MHZ,
+	DVB_DVB_SRC_BANDWIDTH_BANDWIDTH_6_MHZ,
+	DVB_DVB_SRC_BANDWIDTH_BANDWIDTH_AUTO
+} DVBDvbSrcBandwidth;
+
+typedef enum  {
+	DVB_DVB_SRC_GUARD_GUARD_INTERVAL_1_32,
+	DVB_DVB_SRC_GUARD_GUARD_INTERVAL_1_16,
+	DVB_DVB_SRC_GUARD_GUARD_INTERVAL_1_8,
+	DVB_DVB_SRC_GUARD_GUARD_INTERVAL_1_4,
+	DVB_DVB_SRC_GUARD_GUARD_INTERVAL_AUTO
+} DVBDvbSrcGuard;
+
+typedef enum  {
+	DVB_DVB_SRC_HIERARCHY_HIERARCHY_NONE,
+	DVB_DVB_SRC_HIERARCHY_HIERARCHY_1,
+	DVB_DVB_SRC_HIERARCHY_HIERARCHY_2,
+	DVB_DVB_SRC_HIERARCHY_HIERARCHY_4,
+	DVB_DVB_SRC_HIERARCHY_HIERARCHY_AUTO
+} DVBDvbSrcHierarchy;
+
+typedef enum  {
+	DVB_DVB_SRC_INVERSION_INVERSION_OFF,
+	DVB_DVB_SRC_INVERSION_INVERSION_ON,
+	DVB_DVB_SRC_INVERSION_INVERSION_AUTO
+} DVBDvbSrcInversion;
+
 
 
+GType dvb_dvb_src_code_rate_get_type (void);
+GType dvb_dvb_src_modulation_get_type (void);
+GType dvb_dvb_src_transmission_mode_get_type (void);
+GType dvb_dvb_src_bandwidth_get_type (void);
+GType dvb_dvb_src_guard_get_type (void);
+GType dvb_dvb_src_hierarchy_get_type (void);
+GType dvb_dvb_src_inversion_get_type (void);
+DVBDvbSrcBandwidth dvb_get_bandwidth_val (guint bandwidth);
+DVBDvbSrcHierarchy dvb_get_hierarchy_val (guint hierarchy);
+DVBDvbSrcModulation dvb_get_modulation_val (const char* constellation);
+DVBDvbSrcCodeRate dvb_get_code_rate_val (const char* code_rate_string);
+DVBDvbSrcGuard dvb_get_guard_interval_val (guint guard);
+DVBDvbSrcTransmissionMode dvb_get_transmission_mode_val (const char* transmode);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -107,6 +195,7 @@ GType dvb_dvb_src_inversion_get_type (void) {
      * @bandwith: 0, 6, 7 or 8
      */
 DVBDvbSrcBandwidth dvb_get_bandwidth_val (guint bandwidth) {
+	DVBDvbSrcBandwidth result;
 	DVBDvbSrcBandwidth val;
 	val = 0;
 	switch (bandwidth) {
@@ -131,7 +220,8 @@ DVBDvbSrcBandwidth dvb_get_bandwidth_val (guint bandwidth) {
 			break;
 		}
 	}
-	return val;
+	result = val;
+	return result;
 }
 
 
@@ -140,6 +230,7 @@ DVBDvbSrcBandwidth dvb_get_bandwidth_val (guint bandwidth) {
      * If value doesn't match one of above HIERARCHY_AUTO is returned.
      */
 DVBDvbSrcHierarchy dvb_get_hierarchy_val (guint hierarchy) {
+	DVBDvbSrcHierarchy result;
 	DVBDvbSrcHierarchy val;
 	val = 0;
 	switch (hierarchy) {
@@ -169,7 +260,8 @@ DVBDvbSrcHierarchy dvb_get_hierarchy_val (guint hierarchy) {
 			break;
 		}
 	}
-	return val;
+	result = val;
+	return result;
 }
 
 
@@ -178,6 +270,7 @@ DVBDvbSrcHierarchy dvb_get_hierarchy_val (guint hierarchy) {
      * If value doesn't match one of above QAM_AUTO is returned.
      */
 DVBDvbSrcModulation dvb_get_modulation_val (const char* constellation) {
+	DVBDvbSrcModulation result;
 	DVBDvbSrcModulation val;
 	g_return_val_if_fail (constellation != NULL, 0);
 	val = 0;
@@ -206,7 +299,8 @@ DVBDvbSrcModulation dvb_get_modulation_val (const char* constellation) {
 			}
 		}
 	}
-	return val;
+	result = val;
+	return result;
 }
 
 
@@ -216,6 +310,7 @@ DVBDvbSrcModulation dvb_get_modulation_val (const char* constellation) {
      * If value doesn't match one of above FEC_AUTO is returned.
      */
 DVBDvbSrcCodeRate dvb_get_code_rate_val (const char* code_rate_string) {
+	DVBDvbSrcCodeRate result;
 	DVBDvbSrcCodeRate val;
 	g_return_val_if_fail (code_rate_string != NULL, 0);
 	val = 0;
@@ -256,7 +351,8 @@ DVBDvbSrcCodeRate dvb_get_code_rate_val (const char* code_rate_string) {
 			}
 		}
 	}
-	return val;
+	result = val;
+	return result;
 }
 
 
@@ -265,6 +361,7 @@ DVBDvbSrcCodeRate dvb_get_code_rate_val (const char* code_rate_string) {
      * If value doesn't match one of above GUARD_INTERVAL_AUTO is returned.
      */
 DVBDvbSrcGuard dvb_get_guard_interval_val (guint guard) {
+	DVBDvbSrcGuard result;
 	DVBDvbSrcGuard val;
 	val = 0;
 	switch (guard) {
@@ -294,7 +391,8 @@ DVBDvbSrcGuard dvb_get_guard_interval_val (guint guard) {
 			break;
 		}
 	}
-	return val;
+	result = val;
+	return result;
 }
 
 
@@ -303,6 +401,7 @@ DVBDvbSrcGuard dvb_get_guard_interval_val (guint guard) {
      * If value doesn't match one of above TRANSMISSION_MODE_AUTO is returned.
      */
 DVBDvbSrcTransmissionMode dvb_get_transmission_mode_val (const char* transmode) {
+	DVBDvbSrcTransmissionMode result;
 	DVBDvbSrcTransmissionMode val;
 	g_return_val_if_fail (transmode != NULL, 0);
 	val = 0;
@@ -315,7 +414,8 @@ DVBDvbSrcTransmissionMode dvb_get_transmission_mode_val (const char* transmode)
 			val = DVB_DVB_SRC_TRANSMISSION_MODE_TRANSMISSION_MODE_AUTO;
 		}
 	}
-	return val;
+	result = val;
+	return result;
 }
 
 
