@@ -17,12 +17,37 @@
  * along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <src/Recording.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
+#include <gio/gio.h>
+#include <time.h>
 #include <stdio.h>
-#include "src/Utils.h"
 
 
+#define DVB_TYPE_RECORDING (dvb_recording_get_type ())
+#define DVB_RECORDING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_RECORDING, DVBRecording))
+#define DVB_RECORDING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_RECORDING, DVBRecordingClass))
+#define DVB_IS_RECORDING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_RECORDING))
+#define DVB_IS_RECORDING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_RECORDING))
+#define DVB_RECORDING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_RECORDING, DVBRecordingClass))
 
+typedef struct _DVBRecording DVBRecording;
+typedef struct _DVBRecordingClass DVBRecordingClass;
+typedef struct _DVBRecordingPrivate DVBRecordingPrivate;
+
+/**
+     * This class represents a finished recording
+     */
+struct _DVBRecording {
+	GObject parent_instance;
+	DVBRecordingPrivate * priv;
+};
+
+struct _DVBRecordingClass {
+	GObjectClass parent_class;
+};
 
 struct _DVBRecordingPrivate {
 	guint32 _Id;
@@ -33,8 +58,13 @@ struct _DVBRecordingPrivate {
 	char* _Description;
 	struct tm _StartTime;
 	gint64 _Length;
+	GFileMonitor* _file_monitor;
 };
 
+
+static gpointer dvb_recording_parent_class = NULL;
+
+GType dvb_recording_get_type (void);
 #define DVB_RECORDING_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DVB_TYPE_RECORDING, DVBRecordingPrivate))
 enum  {
 	DVB_RECORDING_DUMMY_PROPERTY,
@@ -44,10 +74,39 @@ enum  {
 	DVB_RECORDING_LOCATION,
 	DVB_RECORDING_NAME,
 	DVB_RECORDING_DESCRIPTION,
-	DVB_RECORDING_LENGTH
+	DVB_RECORDING_LENGTH,
+	DVB_RECORDING_FILE_MONITOR
 };
-static gpointer dvb_recording_parent_class = NULL;
+void dvb_recording_get_StartTime (DVBRecording* self, struct tm* value);
+guint* dvb_recording_get_start (DVBRecording* self, int* result_length1);
+GFile* dvb_recording_get_Location (DVBRecording* self);
+char* dvb_recording_serialize (DVBRecording* self);
+void dvb_recording_save_to_disk (DVBRecording* self, GError** error);
+const char* dvb_recording_get_Name (DVBRecording* self);
+const char* dvb_recording_get_Description (DVBRecording* self);
+guint32 dvb_recording_get_Id (DVBRecording* self);
+const char* dvb_recording_get_ChannelName (DVBRecording* self);
+gint64 dvb_recording_get_Length (DVBRecording* self);
+char* dvb_utils_read_file_contents (GFile* file, GError** error);
+DVBRecording* dvb_recording_new (void);
+DVBRecording* dvb_recording_construct (GType object_type);
+void dvb_recording_set_Id (DVBRecording* self, guint32 value);
+void dvb_recording_set_ChannelName (DVBRecording* self, const char* value);
+void dvb_recording_set_Location (DVBRecording* self, GFile* value);
+struct tm dvb_utils_create_time (gint year, gint month, gint day, gint hour, gint minute, gint second);
+void dvb_recording_set_StartTime (DVBRecording* self, struct tm* value);
+void dvb_recording_set_Length (DVBRecording* self, gint64 value);
+void dvb_recording_set_Name (DVBRecording* self, const char* value);
+void dvb_recording_set_Description (DVBRecording* self, const char* value);
+DVBRecording* dvb_recording_deserialize (GFile* file, GError** error);
+guint dvb_recording_get_ChannelSid (DVBRecording* self);
+void dvb_recording_set_ChannelSid (DVBRecording* self, guint value);
+GFileMonitor* dvb_recording_get_file_monitor (DVBRecording* self);
+void dvb_recording_set_file_monitor (DVBRecording* self, GFileMonitor* value);
 static void dvb_recording_finalize (GObject* obj);
+static void dvb_recording_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
+static void dvb_recording_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static gint _vala_array_length (gpointer array);
 static int _vala_strcmp0 (const char * str1, const char * str2);
@@ -55,12 +114,14 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 guint* dvb_recording_get_start (DVBRecording* self, int* result_length1) {
-	guint* _tmp0;
-	guint* _tmp1;
+	guint* result;
+	guint* _tmp0_;
+	guint* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = (_tmp0 = g_new0 (guint, 5), _tmp0[0] = (guint) (self->priv->_StartTime.tm_year + 1900), _tmp0[1] = (guint) (self->priv->_StartTime.tm_mon + 1), _tmp0[2] = (guint) self->priv->_StartTime.tm_mday, _tmp0[3] = (guint) self->priv->_StartTime.tm_hour, _tmp0[4] = (guint) self->priv->_StartTime.tm_min, _tmp0), *result_length1 = 5, _tmp1);
+	_tmp0_ = NULL;
+	_tmp1_ = NULL;
+	result = (_tmp1_ = (_tmp0_ = g_new0 (guint, 5), _tmp0_[0] = (guint) (self->priv->_StartTime.tm_year + 1900), _tmp0_[1] = (guint) (self->priv->_StartTime.tm_mon + 1), _tmp0_[2] = (guint) self->priv->_StartTime.tm_mday, _tmp0_[3] = (guint) self->priv->_StartTime.tm_hour, _tmp0_[4] = (guint) self->priv->_StartTime.tm_min, _tmp0_), *result_length1 = 5, _tmp1_);
+	return result;
 }
 
 
@@ -69,49 +130,49 @@ guint* dvb_recording_get_start (DVBRecording* self, int* result_length1) {
          * in the directory of this.Location
          */
 void dvb_recording_save_to_disk (DVBRecording* self, GError** error) {
-	GError * inner_error;
+	GError * _inner_error_;
 	GFile* parentdir;
 	GFile* recfile;
-	char* _tmp0;
+	char* _tmp0_;
 	GFileOutputStream* stream;
 	char* text;
 	g_return_if_fail (self != NULL);
-	inner_error = NULL;
+	_inner_error_ = NULL;
 	parentdir = g_file_get_parent (self->priv->_Location);
 	recfile = g_file_get_child (parentdir, "info.rec");
-	_tmp0 = NULL;
-	g_debug ("Recording.vala:57: Saving recording to %s", _tmp0 = g_file_get_path (recfile));
-	_tmp0 = (g_free (_tmp0), NULL);
+	_tmp0_ = NULL;
+	g_debug ("Recording.vala:58: Saving recording to %s", _tmp0_ = g_file_get_path (recfile));
+	_tmp0_ = (g_free (_tmp0_), NULL);
 	if (g_file_query_exists (recfile, NULL)) {
-		g_debug ("Recording.vala:60: Deleting old info.rec");
-		g_file_delete (recfile, NULL, &inner_error);
-		if (inner_error != NULL) {
-			g_propagate_error (error, inner_error);
+		g_debug ("Recording.vala:61: Deleting old info.rec");
+		g_file_delete (recfile, NULL, &_inner_error_);
+		if (_inner_error_ != NULL) {
+			g_propagate_error (error, _inner_error_);
 			(parentdir == NULL) ? NULL : (parentdir = (g_object_unref (parentdir), NULL));
 			(recfile == NULL) ? NULL : (recfile = (g_object_unref (recfile), NULL));
 			return;
 		}
 	}
-	stream = g_file_create (recfile, 0, NULL, &inner_error);
-	if (inner_error != NULL) {
-		g_propagate_error (error, inner_error);
+	stream = g_file_create (recfile, 0, NULL, &_inner_error_);
+	if (_inner_error_ != NULL) {
+		g_propagate_error (error, _inner_error_);
 		(parentdir == NULL) ? NULL : (parentdir = (g_object_unref (parentdir), NULL));
 		(recfile == NULL) ? NULL : (recfile = (g_object_unref (recfile), NULL));
 		return;
 	}
 	text = dvb_recording_serialize (self);
-	g_output_stream_write ((GOutputStream*) stream, text, (gsize) strlen (text), NULL, &inner_error);
-	if (inner_error != NULL) {
-		g_propagate_error (error, inner_error);
+	g_output_stream_write ((GOutputStream*) stream, text, strlen (text), NULL, &_inner_error_);
+	if (_inner_error_ != NULL) {
+		g_propagate_error (error, _inner_error_);
 		(parentdir == NULL) ? NULL : (parentdir = (g_object_unref (parentdir), NULL));
 		(recfile == NULL) ? NULL : (recfile = (g_object_unref (recfile), NULL));
 		(stream == NULL) ? NULL : (stream = (g_object_unref (stream), NULL));
 		text = (g_free (text), NULL);
 		return;
 	}
-	g_output_stream_close ((GOutputStream*) stream, NULL, &inner_error);
-	if (inner_error != NULL) {
-		g_propagate_error (error, inner_error);
+	g_output_stream_close ((GOutputStream*) stream, NULL, &_inner_error_);
+	if (_inner_error_ != NULL) {
+		g_propagate_error (error, _inner_error_);
 		(parentdir == NULL) ? NULL : (parentdir = (g_object_unref (parentdir), NULL));
 		(recfile == NULL) ? NULL : (recfile = (g_object_unref (recfile), NULL));
 		(stream == NULL) ? NULL : (stream = (g_object_unref (stream), NULL));
@@ -126,74 +187,79 @@ void dvb_recording_save_to_disk (DVBRecording* self, GError** error) {
 
 
 char* dvb_recording_serialize (DVBRecording* self) {
-	guint* _tmp1;
+	char* result;
+	guint* _tmp1_;
 	gint started_size;
 	gint started_length1;
-	gint _tmp0;
+	gint _tmp0_;
 	guint* started;
-	const char* _tmp2;
-	const char* _tmp3;
-	char* _tmp4;
-	char* _tmp5;
-	char* _tmp6;
+	const char* _tmp2_;
+	const char* _tmp3_;
+	char* _tmp4_;
+	char* _tmp5_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp1 = NULL;
-	started = (_tmp1 = dvb_recording_get_start (self, &_tmp0), started_length1 = _tmp0, started_size = started_length1, _tmp1);
-	_tmp2 = NULL;
+	_tmp1_ = NULL;
+	started = (_tmp1_ = dvb_recording_get_start (self, &_tmp0_), started_length1 = _tmp0_, started_size = started_length1, _tmp1_);
+	_tmp2_ = NULL;
 	if (self->priv->_Name == NULL) {
-		_tmp2 = "";
+		_tmp2_ = "";
 	} else {
-		_tmp2 = self->priv->_Name;
+		_tmp2_ = self->priv->_Name;
 	}
-	_tmp3 = NULL;
+	_tmp3_ = NULL;
 	if (self->priv->_Description == NULL) {
-		_tmp3 = "";
+		_tmp3_ = "";
 	} else {
-		_tmp3 = self->priv->_Description;
+		_tmp3_ = self->priv->_Description;
 	}
-	_tmp4 = NULL;
-	_tmp5 = NULL;
-	_tmp6 = NULL;
-	return (_tmp6 = (_tmp5 = g_strdup_printf ("%u\n%s\n%s\n%u-%u-%u %u:%u\n%" G_GINT64_FORMAT "\n%s\n%s", self->priv->_Id, self->priv->_ChannelName, _tmp4 = g_file_get_path (self->priv->_Location), started[0], started[1], started[2], started[3], started[4], self->priv->_Length, _tmp2, _tmp3), _tmp4 = (g_free (_tmp4), NULL), _tmp5), started = (g_free (started), NULL), _tmp6);
+	_tmp4_ = NULL;
+	_tmp5_ = NULL;
+	result = (_tmp5_ = g_strdup_printf ("%u\n%s\n%s\n%u-%u-%u %u:%u\n%" G_GINT64_FORMAT "\n%s\n%s", self->priv->_Id, self->priv->_ChannelName, _tmp4_ = g_file_get_path (self->priv->_Location), started[0], started[1], started[2], started[3], started[4], self->priv->_Length, _tmp2_, _tmp3_), _tmp4_ = (g_free (_tmp4_), NULL), _tmp5_);
+	started = (g_free (started), NULL);
+	return result;
+	started = (g_free (started), NULL);
 }
 
 
 /* TODO throw error*/
 DVBRecording* dvb_recording_deserialize (GFile* file, GError** error) {
-	GError * inner_error;
+	DVBRecording* result;
+	GError * _inner_error_;
 	char* contents;
-	char** _tmp2;
+	char** _tmp1_;
 	gint fields_size;
 	gint fields_length1;
-	char** _tmp1;
+	char** _tmp0_;
 	char** fields;
 	DVBRecording* rec;
 	char* field;
 	gint i;
-	char* _tmp4;
-	const char* _tmp3;
-	DVBRecording* _tmp12;
 	g_return_val_if_fail (file != NULL, NULL);
-	inner_error = NULL;
-	contents = dvb_utils_read_file_contents (file, &inner_error);
-	if (inner_error != NULL) {
-		g_propagate_error (error, inner_error);
+	_inner_error_ = NULL;
+	contents = dvb_utils_read_file_contents (file, &_inner_error_);
+	if (_inner_error_ != NULL) {
+		g_propagate_error (error, _inner_error_);
 		return NULL;
 	}
 	if (contents == NULL) {
-		DVBRecording* _tmp0;
-		_tmp0 = NULL;
-		return (_tmp0 = NULL, contents = (g_free (contents), NULL), _tmp0);
+		result = NULL;
+		contents = (g_free (contents), NULL);
+		return result;
 	}
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	fields = (_tmp2 = _tmp1 = g_strsplit (contents, "\n", 7), fields_length1 = _vala_array_length (_tmp1), fields_size = fields_length1, _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	fields = (_tmp1_ = _tmp0_ = g_strsplit (contents, "\n", 7), fields_length1 = _vala_array_length (_tmp0_), fields_size = fields_length1, _tmp1_);
 	rec = dvb_recording_new ();
 	field = NULL;
 	i = 0;
-	_tmp4 = NULL;
-	_tmp3 = NULL;
-	while ((field = (_tmp4 = (_tmp3 = fields[i], (_tmp3 == NULL) ? NULL : g_strdup (_tmp3)), field = (g_free (field), NULL), _tmp4)) != NULL) {
+	while (TRUE) {
+		char* _tmp3_;
+		const char* _tmp2_;
+		_tmp3_ = NULL;
+		_tmp2_ = NULL;
+		if (!((field = (_tmp3_ = (_tmp2_ = fields[i], (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_)), field = (g_free (field), NULL), _tmp3_)) != NULL)) {
+			break;
+		}
 		switch (i) {
 			case 0:
 			{
@@ -210,10 +276,10 @@ DVBRecording* dvb_recording_deserialize (GFile* file, GError** error) {
 				if (_vala_strcmp0 (field, "") == 0) {
 					dvb_recording_set_Location (rec, NULL);
 				} else {
-					GFile* _tmp5;
-					_tmp5 = NULL;
-					dvb_recording_set_Location (rec, _tmp5 = g_file_new_for_path (field));
-					(_tmp5 == NULL) ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL));
+					GFile* _tmp4_;
+					_tmp4_ = NULL;
+					dvb_recording_set_Location (rec, _tmp4_ = g_file_new_for_path (field));
+					(_tmp4_ == NULL) ? NULL : (_tmp4_ = (g_object_unref (_tmp4_), NULL));
 				}
 				break;
 			}
@@ -225,43 +291,43 @@ DVBRecording* dvb_recording_deserialize (GFile* file, GError** error) {
 					gint day;
 					gint hour;
 					gint minute;
-					gboolean _tmp6;
-					gboolean _tmp7;
-					gboolean _tmp8;
-					gboolean _tmp9;
+					gboolean _tmp5_;
+					gboolean _tmp6_;
+					gboolean _tmp7_;
+					gboolean _tmp8_;
 					year = 0;
 					month = 0;
 					day = 0;
 					hour = 0;
 					minute = 0;
-					sscanf (field, "%d-%d-%d %d:%d", &year, &month, &day, &hour, &minute, NULL);
-					_tmp6 = FALSE;
-					_tmp7 = FALSE;
-					_tmp8 = FALSE;
-					_tmp9 = FALSE;
+					sscanf (field, "%d-%d-%d %d:%d", &year, &month, &day, &hour, &minute);
+					_tmp5_ = FALSE;
+					_tmp6_ = FALSE;
+					_tmp7_ = FALSE;
+					_tmp8_ = FALSE;
 					if (year >= 1900) {
-						_tmp9 = month >= 1;
+						_tmp8_ = month >= 1;
 					} else {
-						_tmp9 = FALSE;
+						_tmp8_ = FALSE;
 					}
-					if (_tmp9) {
-						_tmp8 = day >= 1;
+					if (_tmp8_) {
+						_tmp7_ = day >= 1;
 					} else {
-						_tmp8 = FALSE;
+						_tmp7_ = FALSE;
 					}
-					if (_tmp8) {
-						_tmp7 = hour >= 0;
+					if (_tmp7_) {
+						_tmp6_ = hour >= 0;
 					} else {
-						_tmp7 = FALSE;
+						_tmp6_ = FALSE;
 					}
-					if (_tmp7) {
-						_tmp6 = minute >= 0;
+					if (_tmp6_) {
+						_tmp5_ = minute >= 0;
 					} else {
-						_tmp6 = FALSE;
+						_tmp5_ = FALSE;
 					}
-					if (_tmp6) {
-						struct tm _tmp10 = {0};
-						dvb_recording_set_StartTime (rec, (_tmp10 = dvb_utils_create_time (year, month, day, hour, minute, 0), &_tmp10));
+					if (_tmp5_) {
+						struct tm _tmp9_ = {0};
+						dvb_recording_set_StartTime (rec, (_tmp9_ = dvb_utils_create_time (year, month, day, hour, minute, 0), &_tmp9_));
 					}
 					break;
 				}
@@ -273,14 +339,14 @@ DVBRecording* dvb_recording_deserialize (GFile* file, GError** error) {
 			}
 			case 5:
 			{
-				const char* _tmp11;
-				_tmp11 = NULL;
+				const char* _tmp10_;
+				_tmp10_ = NULL;
 				if (_vala_strcmp0 (field, "") == 0) {
-					_tmp11 = NULL;
+					_tmp10_ = NULL;
 				} else {
-					_tmp11 = field;
+					_tmp10_ = field;
 				}
-				dvb_recording_set_Name (rec, _tmp11);
+				dvb_recording_set_Name (rec, _tmp10_);
 				break;
 			}
 			default:
@@ -291,8 +357,11 @@ DVBRecording* dvb_recording_deserialize (GFile* file, GError** error) {
 		}
 		i++;
 	}
-	_tmp12 = NULL;
-	return (_tmp12 = rec, contents = (g_free (contents), NULL), fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL), field = (g_free (field), NULL), _tmp12);
+	result = rec;
+	contents = (g_free (contents), NULL);
+	fields = (_vala_array_free (fields, fields_length1, (GDestroyNotify) g_free), NULL);
+	field = (g_free (field), NULL);
+	return result;
 }
 
 
@@ -312,8 +381,10 @@ DVBRecording* dvb_recording_new (void) {
 
 
 guint32 dvb_recording_get_Id (DVBRecording* self) {
+	guint32 result;
 	g_return_val_if_fail (self != NULL, 0U);
-	return self->priv->_Id;
+	result = self->priv->_Id;
+	return result;
 }
 
 
@@ -325,8 +396,10 @@ void dvb_recording_set_Id (DVBRecording* self, guint32 value) {
 
 
 guint dvb_recording_get_ChannelSid (DVBRecording* self) {
+	guint result;
 	g_return_val_if_fail (self != NULL, 0U);
-	return self->priv->_ChannelSid;
+	result = self->priv->_ChannelSid;
+	return result;
 }
 
 
@@ -338,76 +411,86 @@ void dvb_recording_set_ChannelSid (DVBRecording* self, guint value) {
 
 
 const char* dvb_recording_get_ChannelName (DVBRecording* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_ChannelName;
+	result = self->priv->_ChannelName;
+	return result;
 }
 
 
 void dvb_recording_set_ChannelName (DVBRecording* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_ChannelName = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_ChannelName = (g_free (self->priv->_ChannelName), NULL), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_ChannelName = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_ChannelName = (g_free (self->priv->_ChannelName), NULL), _tmp1_);
 	g_object_notify ((GObject *) self, "ChannelName");
 }
 
 
 GFile* dvb_recording_get_Location (DVBRecording* self) {
+	GFile* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_Location;
+	result = self->priv->_Location;
+	return result;
 }
 
 
 void dvb_recording_set_Location (DVBRecording* self, GFile* value) {
-	GFile* _tmp2;
-	GFile* _tmp1;
+	GFile* _tmp1_;
+	GFile* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_Location = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_Location == NULL) ? NULL : (self->priv->_Location = (g_object_unref (self->priv->_Location), NULL)), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_Location = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_)), (self->priv->_Location == NULL) ? NULL : (self->priv->_Location = (g_object_unref (self->priv->_Location), NULL)), _tmp1_);
 	g_object_notify ((GObject *) self, "Location");
 }
 
 
 const char* dvb_recording_get_Name (DVBRecording* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_Name;
+	result = self->priv->_Name;
+	return result;
 }
 
 
 void dvb_recording_set_Name (DVBRecording* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_Name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_Name = (g_free (self->priv->_Name), NULL), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_Name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_Name = (g_free (self->priv->_Name), NULL), _tmp1_);
 	g_object_notify ((GObject *) self, "Name");
 }
 
 
 const char* dvb_recording_get_Description (DVBRecording* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_Description;
+	result = self->priv->_Description;
+	return result;
 }
 
 
 void dvb_recording_set_Description (DVBRecording* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_Description = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_Description = (g_free (self->priv->_Description), NULL), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_Description = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_Description = (g_free (self->priv->_Description), NULL), _tmp1_);
 	g_object_notify ((GObject *) self, "Description");
 }
 
 
 void dvb_recording_get_StartTime (DVBRecording* self, struct tm* value) {
+	struct tm result;
 	g_return_if_fail (self != NULL);
-	*value = self->priv->_StartTime;
+	result = self->priv->_StartTime;
+	*value = result;
 	return;
 }
 
@@ -419,8 +502,10 @@ void dvb_recording_set_StartTime (DVBRecording* self, struct tm* value) {
 
 
 gint64 dvb_recording_get_Length (DVBRecording* self) {
+	gint64 result;
 	g_return_val_if_fail (self != NULL, 0LL);
-	return self->priv->_Length;
+	result = self->priv->_Length;
+	return result;
 }
 
 
@@ -431,6 +516,69 @@ void dvb_recording_set_Length (DVBRecording* self, gint64 value) {
 }
 
 
+GFileMonitor* dvb_recording_get_file_monitor (DVBRecording* self) {
+	GFileMonitor* result;
+	g_return_val_if_fail (self != NULL, NULL);
+	result = self->priv->_file_monitor;
+	return result;
+}
+
+
+void dvb_recording_set_file_monitor (DVBRecording* self, GFileMonitor* value) {
+	GFileMonitor* _tmp1_;
+	GFileMonitor* _tmp0_;
+	g_return_if_fail (self != NULL);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_file_monitor = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_)), (self->priv->_file_monitor == NULL) ? NULL : (self->priv->_file_monitor = (g_object_unref (self->priv->_file_monitor), NULL)), _tmp1_);
+	g_object_notify ((GObject *) self, "file-monitor");
+}
+
+
+static void dvb_recording_class_init (DVBRecordingClass * klass) {
+	dvb_recording_parent_class = g_type_class_peek_parent (klass);
+	g_type_class_add_private (klass, sizeof (DVBRecordingPrivate));
+	G_OBJECT_CLASS (klass)->get_property = dvb_recording_get_property;
+	G_OBJECT_CLASS (klass)->set_property = dvb_recording_set_property;
+	G_OBJECT_CLASS (klass)->finalize = dvb_recording_finalize;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_ID, g_param_spec_uint ("Id", "Id", "Id", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_CHANNEL_SID, g_param_spec_uint ("ChannelSid", "ChannelSid", "ChannelSid", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_CHANNEL_NAME, g_param_spec_string ("ChannelName", "ChannelName", "ChannelName", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_LOCATION, g_param_spec_object ("Location", "Location", "Location", G_TYPE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_NAME, g_param_spec_string ("Name", "Name", "Name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_DESCRIPTION, g_param_spec_string ("Description", "Description", "Description", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_LENGTH, g_param_spec_int64 ("Length", "Length", "Length", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_FILE_MONITOR, g_param_spec_object ("file-monitor", "file-monitor", "file-monitor", G_TYPE_FILE_MONITOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+}
+
+
+static void dvb_recording_instance_init (DVBRecording * self) {
+	self->priv = DVB_RECORDING_GET_PRIVATE (self);
+}
+
+
+static void dvb_recording_finalize (GObject* obj) {
+	DVBRecording * self;
+	self = DVB_RECORDING (obj);
+	self->priv->_ChannelName = (g_free (self->priv->_ChannelName), NULL);
+	(self->priv->_Location == NULL) ? NULL : (self->priv->_Location = (g_object_unref (self->priv->_Location), NULL));
+	self->priv->_Name = (g_free (self->priv->_Name), NULL);
+	self->priv->_Description = (g_free (self->priv->_Description), NULL);
+	(self->priv->_file_monitor == NULL) ? NULL : (self->priv->_file_monitor = (g_object_unref (self->priv->_file_monitor), NULL));
+	G_OBJECT_CLASS (dvb_recording_parent_class)->finalize (obj);
+}
+
+
+GType dvb_recording_get_type (void) {
+	static GType dvb_recording_type_id = 0;
+	if (dvb_recording_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (DVBRecordingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dvb_recording_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DVBRecording), 0, (GInstanceInitFunc) dvb_recording_instance_init, NULL };
+		dvb_recording_type_id = g_type_register_static (G_TYPE_OBJECT, "DVBRecording", &g_define_type_info, 0);
+	}
+	return dvb_recording_type_id;
+}
+
+
 static void dvb_recording_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	DVBRecording * self;
 	gpointer boxed;
@@ -457,6 +605,9 @@ static void dvb_recording_get_property (GObject * object, guint property_id, GVa
 		case DVB_RECORDING_LENGTH:
 		g_value_set_int64 (value, dvb_recording_get_Length (self));
 		break;
+		case DVB_RECORDING_FILE_MONITOR:
+		g_value_set_object (value, dvb_recording_get_file_monitor (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -489,6 +640,9 @@ static void dvb_recording_set_property (GObject * object, guint property_id, con
 		case DVB_RECORDING_LENGTH:
 		dvb_recording_set_Length (self, g_value_get_int64 (value));
 		break;
+		case DVB_RECORDING_FILE_MONITOR:
+		dvb_recording_set_file_monitor (self, g_value_get_object (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -496,49 +650,7 @@ static void dvb_recording_set_property (GObject * object, guint property_id, con
 }
 
 
-static void dvb_recording_class_init (DVBRecordingClass * klass) {
-	dvb_recording_parent_class = g_type_class_peek_parent (klass);
-	g_type_class_add_private (klass, sizeof (DVBRecordingPrivate));
-	G_OBJECT_CLASS (klass)->get_property = dvb_recording_get_property;
-	G_OBJECT_CLASS (klass)->set_property = dvb_recording_set_property;
-	G_OBJECT_CLASS (klass)->finalize = dvb_recording_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_ID, g_param_spec_uint ("Id", "Id", "Id", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_CHANNEL_SID, g_param_spec_uint ("ChannelSid", "ChannelSid", "ChannelSid", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_CHANNEL_NAME, g_param_spec_string ("ChannelName", "ChannelName", "ChannelName", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_LOCATION, g_param_spec_object ("Location", "Location", "Location", G_TYPE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_NAME, g_param_spec_string ("Name", "Name", "Name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_DESCRIPTION, g_param_spec_string ("Description", "Description", "Description", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_RECORDING_LENGTH, g_param_spec_int64 ("Length", "Length", "Length", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-}
-
-
-static void dvb_recording_instance_init (DVBRecording * self) {
-	self->priv = DVB_RECORDING_GET_PRIVATE (self);
-}
-
-
-static void dvb_recording_finalize (GObject* obj) {
-	DVBRecording * self;
-	self = DVB_RECORDING (obj);
-	self->priv->_ChannelName = (g_free (self->priv->_ChannelName), NULL);
-	(self->priv->_Location == NULL) ? NULL : (self->priv->_Location = (g_object_unref (self->priv->_Location), NULL));
-	self->priv->_Name = (g_free (self->priv->_Name), NULL);
-	self->priv->_Description = (g_free (self->priv->_Description), NULL);
-	G_OBJECT_CLASS (dvb_recording_parent_class)->finalize (obj);
-}
-
-
-GType dvb_recording_get_type (void) {
-	static GType dvb_recording_type_id = 0;
-	if (dvb_recording_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (DVBRecordingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dvb_recording_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DVBRecording), 0, (GInstanceInitFunc) dvb_recording_instance_init, NULL };
-		dvb_recording_type_id = g_type_register_static (G_TYPE_OBJECT, "DVBRecording", &g_define_type_info, 0);
-	}
-	return dvb_recording_type_id;
-}
-
-
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
 		for (i = 0; i < array_length; i = i + 1) {
@@ -547,6 +659,11 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 			}
 		}
 	}
+}
+
+
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+	_vala_array_destroy (array, array_length, destroy_func);
 	g_free (array);
 }
 
