@@ -17,11 +17,48 @@
  * along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <src/Timer.h>
-#include "src/Utils.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
+#include <gst/gst.h>
+#include <time.h>
 
 
+#define DVB_TYPE_TIMER (dvb_timer_get_type ())
+#define DVB_TIMER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_TIMER, DVBTimer))
+#define DVB_TIMER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_TIMER, DVBTimerClass))
+#define DVB_IS_TIMER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_TIMER))
+#define DVB_IS_TIMER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_TIMER))
+#define DVB_TIMER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_TIMER, DVBTimerClass))
 
+typedef struct _DVBTimer DVBTimer;
+typedef struct _DVBTimerClass DVBTimerClass;
+typedef struct _DVBTimerPrivate DVBTimerPrivate;
+
+#define DVB_TYPE_CHANNEL (dvb_channel_get_type ())
+#define DVB_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_CHANNEL, DVBChannel))
+#define DVB_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_CHANNEL, DVBChannelClass))
+#define DVB_IS_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_CHANNEL))
+#define DVB_IS_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_CHANNEL))
+#define DVB_CHANNEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_CHANNEL, DVBChannelClass))
+
+typedef struct _DVBChannel DVBChannel;
+typedef struct _DVBChannelClass DVBChannelClass;
+
+#define DVB_TYPE_OVERLAP_TYPE (dvb_overlap_type_get_type ())
+
+/**
+     * This class represents an event that should be recorded
+     */
+struct _DVBTimer {
+	GObject parent_instance;
+	DVBTimerPrivate * priv;
+};
+
+struct _DVBTimerClass {
+	GObjectClass parent_class;
+};
 
 struct _DVBTimerPrivate {
 	guint32 _Id;
@@ -33,9 +70,22 @@ struct _DVBTimerPrivate {
 	guint _Hour;
 	guint _Minute;
 	guint _Duration;
+	GstElement* _sink;
 	struct tm starttime;
 };
 
+typedef enum  {
+	DVB_OVERLAP_TYPE_UNKNOWN,
+	DVB_OVERLAP_TYPE_NONE,
+	DVB_OVERLAP_TYPE_PARTIAL,
+	DVB_OVERLAP_TYPE_COMPLETE
+} DVBOverlapType;
+
+
+static gpointer dvb_timer_parent_class = NULL;
+
+GType dvb_timer_get_type (void);
+GType dvb_channel_get_type (void);
 #define DVB_TIMER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DVB_TYPE_TIMER, DVBTimerPrivate))
 enum  {
 	DVB_TIMER_DUMMY_PROPERTY,
@@ -47,15 +97,53 @@ enum  {
 	DVB_TIMER_DAY,
 	DVB_TIMER_HOUR,
 	DVB_TIMER_MINUTE,
-	DVB_TIMER_DURATION
+	DVB_TIMER_DURATION,
+	DVB_TIMER_SINK
 };
-static DVBOverlapType dvb_timer_get_overlap (const time_t* this_start, const time_t* this_end, const time_t* other_start, const time_t* other_end);
-static time_t dvb_timer_get_end_time_timestamp (DVBTimer* self);
-static time_t dvb_timer_get_start_time_timestamp (DVBTimer* self);
 static void dvb_timer_set_Id (DVBTimer* self, guint32 value);
 static void dvb_timer_set_Channel (DVBTimer* self, DVBChannel* value);
-static gpointer dvb_timer_parent_class = NULL;
+void dvb_timer_set_Name (DVBTimer* self, const char* value);
+void dvb_timer_set_Year (DVBTimer* self, guint value);
+void dvb_timer_set_Month (DVBTimer* self, guint value);
+void dvb_timer_set_Day (DVBTimer* self, guint value);
+void dvb_timer_set_Hour (DVBTimer* self, guint value);
+void dvb_timer_set_Minute (DVBTimer* self, guint value);
+void dvb_timer_set_Duration (DVBTimer* self, guint value);
+struct tm dvb_utils_create_time (gint year, gint month, gint day, gint hour, gint minute, gint second);
+DVBTimer* dvb_timer_new (guint32 id, DVBChannel* channel, gint year, gint month, gint day, gint hour, gint minute, guint duration, const char* name);
+DVBTimer* dvb_timer_construct (GType object_type, guint32 id, DVBChannel* channel, gint year, gint month, gint day, gint hour, gint minute, guint duration, const char* name);
+static time_t dvb_timer_get_start_time_timestamp (DVBTimer* self);
+DVBChannel* dvb_timer_get_Channel (DVBTimer* self);
+gboolean dvb_channel_on_same_transport_stream (DVBChannel* self, DVBChannel* channel);
+gboolean dvb_channel_equals (DVBChannel* self, DVBChannel* channel);
+static time_t dvb_timer_get_end_time_timestamp (DVBTimer* self);
+gboolean dvb_timer_conflicts_with (DVBTimer* self, DVBTimer* t2);
+GType dvb_overlap_type_get_type (void);
+static DVBOverlapType dvb_timer_get_overlap (const time_t* this_start, const time_t* this_end, const time_t* other_start, const time_t* other_end);
+DVBOverlapType dvb_timer_get_overlap_local (DVBTimer* self, guint start_year, guint start_month, guint start_day, guint start_hour, guint start_minute, guint duration);
+DVBOverlapType dvb_timer_get_overlap_utc (DVBTimer* self, guint start_year, guint start_month, guint start_day, guint start_hour, guint start_minute, guint duration);
+void dvb_timer_add_to_start_time (DVBTimer* self, gint minutes);
+guint dvb_timer_get_Year (DVBTimer* self);
+guint dvb_timer_get_Month (DVBTimer* self);
+guint dvb_timer_get_Day (DVBTimer* self);
+guint dvb_timer_get_Hour (DVBTimer* self);
+guint dvb_timer_get_Minute (DVBTimer* self);
+guint* dvb_timer_get_start_time (DVBTimer* self, int* result_length1);
+struct tm dvb_timer_get_start_time_time (DVBTimer* self);
+guint* dvb_timer_get_end_time (DVBTimer* self, int* result_length1);
+gboolean dvb_timer_has_expired (DVBTimer* self);
+gboolean dvb_timer_is_start_due (DVBTimer* self);
+gboolean dvb_timer_is_end_due (DVBTimer* self);
+guint dvb_channel_get_Sid (DVBChannel* self);
+guint dvb_timer_get_Duration (DVBTimer* self);
+char* dvb_timer_to_string (DVBTimer* self);
+guint32 dvb_timer_get_Id (DVBTimer* self);
+const char* dvb_timer_get_Name (DVBTimer* self);
+GstElement* dvb_timer_get_sink (DVBTimer* self);
+void dvb_timer_set_sink (DVBTimer* self, GstElement* value);
 static void dvb_timer_finalize (GObject* obj);
+static void dvb_timer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
+static void dvb_timer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
 
 
 
@@ -101,45 +189,52 @@ DVBTimer* dvb_timer_new (guint32 id, DVBChannel* channel, gint year, gint month,
          * Whether the timer conflicts with the other one
          */
 gboolean dvb_timer_conflicts_with (DVBTimer* self, DVBTimer* t2) {
+	gboolean result;
 	time_t this_start;
 	time_t other_start;
-	DVBChannel* _tmp0;
+	DVBChannel* _tmp0_;
 	DVBChannel* t1_c;
-	DVBChannel* _tmp1;
+	DVBChannel* _tmp1_;
 	DVBChannel* t2_c;
-	gboolean _tmp2;
+	gboolean _tmp2_;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (t2 != NULL, FALSE);
 	this_start = dvb_timer_get_start_time_timestamp (self);
 	other_start = dvb_timer_get_start_time_timestamp (t2);
-	_tmp0 = NULL;
-	t1_c = (_tmp0 = self->priv->_Channel, (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0));
-	_tmp1 = NULL;
-	t2_c = (_tmp1 = t2->priv->_Channel, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1));
-	_tmp2 = FALSE;
+	_tmp0_ = NULL;
+	t1_c = (_tmp0_ = self->priv->_Channel, (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_));
+	_tmp1_ = NULL;
+	t2_c = (_tmp1_ = t2->priv->_Channel, (_tmp1_ == NULL) ? NULL : g_object_ref (_tmp1_));
+	_tmp2_ = FALSE;
 	if (dvb_channel_on_same_transport_stream (t1_c, t2_c)) {
-		_tmp2 = !dvb_channel_equals (t1_c, t2_c);
+		_tmp2_ = !dvb_channel_equals (t1_c, t2_c);
 	} else {
-		_tmp2 = FALSE;
+		_tmp2_ = FALSE;
 	}
-	if (_tmp2) {
-		gboolean _tmp3;
+	if (_tmp2_) {
 		/* Recordings on the same TS never conflict as long
 		 as it isn't the same channel*/
-		return (_tmp3 = FALSE, (t1_c == NULL) ? NULL : (t1_c = (g_object_unref (t1_c), NULL)), (t2_c == NULL) ? NULL : (t2_c = (g_object_unref (t2_c), NULL)), _tmp3);
+		result = FALSE;
+		(t1_c == NULL) ? NULL : (t1_c = (g_object_unref (t1_c), NULL));
+		(t2_c == NULL) ? NULL : (t2_c = (g_object_unref (t2_c), NULL));
+		return result;
 	}
 	if (this_start <= other_start) {
 		time_t this_end;
-		gboolean _tmp4;
 		/* No conflict when this timer ends before other starts*/
 		this_end = dvb_timer_get_end_time_timestamp (self);
-		return (_tmp4 = this_end > other_start, (t1_c == NULL) ? NULL : (t1_c = (g_object_unref (t1_c), NULL)), (t2_c == NULL) ? NULL : (t2_c = (g_object_unref (t2_c), NULL)), _tmp4);
+		result = this_end > other_start;
+		(t1_c == NULL) ? NULL : (t1_c = (g_object_unref (t1_c), NULL));
+		(t2_c == NULL) ? NULL : (t2_c = (g_object_unref (t2_c), NULL));
+		return result;
 	} else {
 		time_t other_end;
-		gboolean _tmp5;
 		/* No conflict when other timer ends before this starts*/
 		other_end = dvb_timer_get_end_time_timestamp (t2);
-		return (_tmp5 = other_end > this_start, (t1_c == NULL) ? NULL : (t1_c = (g_object_unref (t1_c), NULL)), (t2_c == NULL) ? NULL : (t2_c = (g_object_unref (t2_c), NULL)), _tmp5);
+		result = other_end > this_start;
+		(t1_c == NULL) ? NULL : (t1_c = (g_object_unref (t1_c), NULL));
+		(t2_c == NULL) ? NULL : (t2_c = (g_object_unref (t2_c), NULL));
+		return result;
 	}
 	(t1_c == NULL) ? NULL : (t1_c = (g_object_unref (t1_c), NULL));
 	(t2_c == NULL) ? NULL : (t2_c = (g_object_unref (t2_c), NULL));
@@ -155,6 +250,7 @@ gboolean dvb_timer_conflicts_with (DVBTimer* self, DVBTimer* t2) {
          * The given time range must be in local time.
          */
 DVBOverlapType dvb_timer_get_overlap_local (DVBTimer* self, guint start_year, guint start_month, guint start_day, guint start_hour, guint start_minute, guint duration) {
+	DVBOverlapType result;
 	time_t this_start;
 	time_t this_end;
 	struct tm other_time;
@@ -167,7 +263,8 @@ DVBOverlapType dvb_timer_get_overlap_local (DVBTimer* self, guint start_year, gu
 	other_start = mktime (&other_time);
 	other_time.tm_min = other_time.tm_min + ((gint) duration);
 	other_end = mktime (&other_time);
-	return dvb_timer_get_overlap (&this_start, &this_end, &other_start, &other_end);
+	result = dvb_timer_get_overlap (&this_start, &this_end, &other_start, &other_end);
+	return result;
 }
 
 
@@ -175,6 +272,7 @@ DVBOverlapType dvb_timer_get_overlap_local (DVBTimer* self, guint start_year, gu
          * Same as get_overlap_local but the given time range is UTC time.
          */
 DVBOverlapType dvb_timer_get_overlap_utc (DVBTimer* self, guint start_year, guint start_month, guint start_day, guint start_hour, guint start_minute, guint duration) {
+	DVBOverlapType result;
 	time_t this_start;
 	time_t this_end;
 	struct tm other_time;
@@ -187,33 +285,41 @@ DVBOverlapType dvb_timer_get_overlap_utc (DVBTimer* self, guint start_year, guin
 	other_start = timegm (&other_time);
 	other_time.tm_min = other_time.tm_min + ((gint) duration);
 	other_end = timegm (&other_time);
-	return dvb_timer_get_overlap (&this_start, &this_end, &other_start, &other_end);
+	result = dvb_timer_get_overlap (&this_start, &this_end, &other_start, &other_end);
+	return result;
 }
 
 
 static DVBOverlapType dvb_timer_get_overlap (const time_t* this_start, const time_t* this_end, const time_t* other_start, const time_t* other_end) {
+	DVBOverlapType result;
 	if ((*this_start) <= (*other_start)) {
 		/* No conflict when this timer ends before other starts*/
 		if ((*this_end) <= (*other_start)) {
 			/* this starts before other and ends before other starts*/
-			return DVB_OVERLAP_TYPE_NONE;
+			result = DVB_OVERLAP_TYPE_NONE;
+			return result;
 		} else {
 			if ((*this_end) >= (*other_end)) {
-				return DVB_OVERLAP_TYPE_COMPLETE;
+				result = DVB_OVERLAP_TYPE_COMPLETE;
+				return result;
 			} else {
-				return DVB_OVERLAP_TYPE_PARTIAL;
+				result = DVB_OVERLAP_TYPE_PARTIAL;
+				return result;
 			}
 		}
 	} else {
 		/* No conflict when other timer ends before this starts*/
 		if ((*this_end) <= (*other_end)) {
 			/* this starts after other and ends before other*/
-			return DVB_OVERLAP_TYPE_PARTIAL;
+			result = DVB_OVERLAP_TYPE_PARTIAL;
+			return result;
 		} else {
 			if ((*this_start) < (*other_end)) {
-				return DVB_OVERLAP_TYPE_PARTIAL;
+				result = DVB_OVERLAP_TYPE_PARTIAL;
+				return result;
 			} else {
-				return DVB_OVERLAP_TYPE_NONE;
+				result = DVB_OVERLAP_TYPE_NONE;
+				return result;
 			}
 		}
 	}
@@ -236,37 +342,44 @@ void dvb_timer_add_to_start_time (DVBTimer* self, gint minutes) {
 
 
 guint* dvb_timer_get_start_time (DVBTimer* self, int* result_length1) {
-	guint* _tmp1;
+	guint* result;
+	guint* _tmp1_;
 	gint start_size;
 	gint start_length1;
-	guint* _tmp0;
+	guint* _tmp0_;
 	guint* start;
-	guint* _tmp2;
+	guint* _tmp2_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	start = (_tmp1 = (_tmp0 = g_new0 (guint, 5), _tmp0[0] = self->priv->_Year, _tmp0[1] = self->priv->_Month, _tmp0[2] = self->priv->_Day, _tmp0[3] = self->priv->_Hour, _tmp0[4] = self->priv->_Minute, _tmp0), start_length1 = 5, start_size = start_length1, _tmp1);
-	_tmp2 = NULL;
-	return (_tmp2 = start, *result_length1 = start_length1, _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	start = (_tmp1_ = (_tmp0_ = g_new0 (guint, 5), _tmp0_[0] = self->priv->_Year, _tmp0_[1] = self->priv->_Month, _tmp0_[2] = self->priv->_Day, _tmp0_[3] = self->priv->_Hour, _tmp0_[4] = self->priv->_Minute, _tmp0_), start_length1 = 5, start_size = start_length1, _tmp1_);
+	_tmp2_ = NULL;
+	result = (_tmp2_ = start, *result_length1 = start_length1, _tmp2_);
+	return result;
+	start = (g_free (start), NULL);
 }
 
 
 struct tm dvb_timer_get_start_time_time (DVBTimer* self) {
-	return self->priv->starttime;
+	struct tm result;
+	result = self->priv->starttime;
+	return result;
 }
 
 
 guint* dvb_timer_get_end_time (DVBTimer* self, int* result_length1) {
-	time_t _tmp1 = {0};
-	struct tm _tmp0 = {0};
+	guint* result;
+	time_t _tmp1_ = {0};
+	struct tm _tmp0_ = {0};
 	struct tm l;
-	guint* _tmp2;
-	guint* _tmp3;
+	guint* _tmp2_;
+	guint* _tmp3_;
 	g_return_val_if_fail (self != NULL, NULL);
-	l = (localtime_r ((_tmp1 = dvb_timer_get_end_time_timestamp (self), &_tmp1), &_tmp0), _tmp0);
-	_tmp2 = NULL;
-	_tmp3 = NULL;
-	return (_tmp3 = (_tmp2 = g_new0 (guint, 5), _tmp2[0] = (guint) (l.tm_year + 1900), _tmp2[1] = (guint) (l.tm_mon + 1), _tmp2[2] = (guint) l.tm_mday, _tmp2[3] = (guint) l.tm_hour, _tmp2[4] = (guint) l.tm_min, _tmp2), *result_length1 = 5, _tmp3);
+	l = (localtime_r ((_tmp1_ = dvb_timer_get_end_time_timestamp (self), &_tmp1_), &_tmp0_), _tmp0_);
+	_tmp2_ = NULL;
+	_tmp3_ = NULL;
+	result = (_tmp3_ = (_tmp2_ = g_new0 (guint, 5), _tmp2_[0] = (guint) (l.tm_year + 1900), _tmp2_[1] = (guint) (l.tm_mon + 1), _tmp2_[2] = (guint) l.tm_mday, _tmp2_[3] = (guint) l.tm_hour, _tmp2_[4] = (guint) l.tm_min, _tmp2_), *result_length1 = 5, _tmp3_);
+	return result;
 }
 
 
@@ -275,18 +388,20 @@ guint* dvb_timer_get_end_time (DVBTimer* self, int* result_length1) {
          * and the timer hasn't expired, yet.
          */
 gboolean dvb_timer_is_start_due (DVBTimer* self) {
-	time_t _tmp0 = {0};
+	gboolean result;
+	time_t _tmp0_ = {0};
 	time_t localtime;
-	gboolean _tmp1;
+	gboolean _tmp1_;
 	g_return_val_if_fail (self != NULL, FALSE);
-	localtime = (time (&_tmp0), _tmp0);
-	_tmp1 = FALSE;
+	localtime = (time (&_tmp0_), _tmp0_);
+	_tmp1_ = FALSE;
 	if ((localtime - mktime (&self->priv->starttime)) >= 0) {
-		_tmp1 = !dvb_timer_has_expired (self);
+		_tmp1_ = !dvb_timer_has_expired (self);
 	} else {
-		_tmp1 = FALSE;
+		_tmp1_ = FALSE;
 	}
-	return _tmp1;
+	result = _tmp1_;
+	return result;
 }
 
 
@@ -294,45 +409,47 @@ gboolean dvb_timer_is_start_due (DVBTimer* self) {
          * Whether the end time of the timer equals the current local time
          */
 gboolean dvb_timer_is_end_due (DVBTimer* self) {
-	time_t _tmp2 = {0};
-	time_t _tmp0 = {0};
-	struct tm _tmp1 = {0};
+	gboolean result;
+	time_t _tmp2_ = {0};
+	time_t _tmp0_ = {0};
+	struct tm _tmp1_ = {0};
 	struct tm localtime;
-	time_t _tmp4 = {0};
-	struct tm _tmp3 = {0};
+	time_t _tmp4_ = {0};
+	struct tm _tmp3_ = {0};
 	struct tm endtime;
-	gboolean _tmp5;
-	gboolean _tmp6;
-	gboolean _tmp7;
-	gboolean _tmp8;
+	gboolean _tmp5_;
+	gboolean _tmp6_;
+	gboolean _tmp7_;
+	gboolean _tmp8_;
 	g_return_val_if_fail (self != NULL, FALSE);
-	localtime = (localtime_r ((_tmp2 = (time (&_tmp0), _tmp0), &_tmp2), &_tmp1), _tmp1);
-	endtime = (localtime_r ((_tmp4 = dvb_timer_get_end_time_timestamp (self), &_tmp4), &_tmp3), _tmp3);
-	_tmp5 = FALSE;
-	_tmp6 = FALSE;
-	_tmp7 = FALSE;
-	_tmp8 = FALSE;
+	localtime = (localtime_r ((_tmp2_ = (time (&_tmp0_), _tmp0_), &_tmp2_), &_tmp1_), _tmp1_);
+	endtime = (localtime_r ((_tmp4_ = dvb_timer_get_end_time_timestamp (self), &_tmp4_), &_tmp3_), _tmp3_);
+	_tmp5_ = FALSE;
+	_tmp6_ = FALSE;
+	_tmp7_ = FALSE;
+	_tmp8_ = FALSE;
 	if (endtime.tm_year == localtime.tm_year) {
-		_tmp8 = endtime.tm_mon == localtime.tm_mon;
+		_tmp8_ = endtime.tm_mon == localtime.tm_mon;
 	} else {
-		_tmp8 = FALSE;
+		_tmp8_ = FALSE;
 	}
-	if (_tmp8) {
-		_tmp7 = endtime.tm_mday == localtime.tm_mday;
+	if (_tmp8_) {
+		_tmp7_ = endtime.tm_mday == localtime.tm_mday;
 	} else {
-		_tmp7 = FALSE;
+		_tmp7_ = FALSE;
 	}
-	if (_tmp7) {
-		_tmp6 = endtime.tm_hour == localtime.tm_hour;
+	if (_tmp7_) {
+		_tmp6_ = endtime.tm_hour == localtime.tm_hour;
 	} else {
-		_tmp6 = FALSE;
+		_tmp6_ = FALSE;
 	}
-	if (_tmp6) {
-		_tmp5 = endtime.tm_min == localtime.tm_min;
+	if (_tmp6_) {
+		_tmp5_ = endtime.tm_min == localtime.tm_min;
 	} else {
-		_tmp5 = FALSE;
+		_tmp5_ = FALSE;
 	}
-	return _tmp5;
+	result = _tmp5_;
+	return result;
 }
 
 
@@ -340,41 +457,51 @@ gboolean dvb_timer_is_end_due (DVBTimer* self) {
          * Whether the timer ends in the past
          */
 gboolean dvb_timer_has_expired (DVBTimer* self) {
-	time_t _tmp0 = {0};
+	gboolean result;
+	time_t _tmp0_ = {0};
 	time_t current_time;
 	time_t end_time;
 	g_return_val_if_fail (self != NULL, FALSE);
-	current_time = (time (&_tmp0), _tmp0);
+	current_time = (time (&_tmp0_), _tmp0_);
 	end_time = dvb_timer_get_end_time_timestamp (self);
-	return end_time < current_time;
+	result = end_time < current_time;
+	return result;
 }
 
 
 char* dvb_timer_to_string (DVBTimer* self) {
+	char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return g_strdup_printf ("channel: %u, start: %u-%u-%u %u:%u, duration: %u", dvb_channel_get_Sid (self->priv->_Channel), self->priv->_Year, self->priv->_Month, self->priv->_Day, self->priv->_Hour, self->priv->_Minute, self->priv->_Duration);
+	result = g_strdup_printf ("channel: %u, start: %u-%u-%u %u:%u, duration: %u", dvb_channel_get_Sid (self->priv->_Channel), self->priv->_Year, self->priv->_Month, self->priv->_Day, self->priv->_Hour, self->priv->_Minute, self->priv->_Duration);
+	return result;
 }
 
 
 static time_t dvb_timer_get_end_time_timestamp (DVBTimer* self) {
+	time_t result;
 	struct tm t;
 	t = dvb_utils_create_time (self->priv->starttime.tm_year + 1900, self->priv->starttime.tm_mon + 1, self->priv->starttime.tm_mday, self->priv->starttime.tm_hour, self->priv->starttime.tm_min, 0);
 	/* TODO Do we change the value of this.starttime each time?*/
 	t.tm_min = t.tm_min + ((gint) self->priv->_Duration);
-	return mktime (&t);
+	result = mktime (&t);
+	return result;
 }
 
 
 static time_t dvb_timer_get_start_time_timestamp (DVBTimer* self) {
+	time_t result;
 	struct tm t;
 	t = dvb_timer_get_start_time_time (self);
-	return mktime (&t);
+	result = mktime (&t);
+	return result;
 }
 
 
 guint32 dvb_timer_get_Id (DVBTimer* self) {
+	guint32 result;
 	g_return_val_if_fail (self != NULL, 0U);
-	return self->priv->_Id;
+	result = self->priv->_Id;
+	return result;
 }
 
 
@@ -386,42 +513,48 @@ static void dvb_timer_set_Id (DVBTimer* self, guint32 value) {
 
 
 DVBChannel* dvb_timer_get_Channel (DVBTimer* self) {
+	DVBChannel* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_Channel;
+	result = self->priv->_Channel;
+	return result;
 }
 
 
 static void dvb_timer_set_Channel (DVBTimer* self, DVBChannel* value) {
-	DVBChannel* _tmp2;
-	DVBChannel* _tmp1;
+	DVBChannel* _tmp1_;
+	DVBChannel* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_Channel = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_Channel == NULL) ? NULL : (self->priv->_Channel = (g_object_unref (self->priv->_Channel), NULL)), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_Channel = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_)), (self->priv->_Channel == NULL) ? NULL : (self->priv->_Channel = (g_object_unref (self->priv->_Channel), NULL)), _tmp1_);
 	g_object_notify ((GObject *) self, "Channel");
 }
 
 
 const char* dvb_timer_get_Name (DVBTimer* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_Name;
+	result = self->priv->_Name;
+	return result;
 }
 
 
 void dvb_timer_set_Name (DVBTimer* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_Name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_Name = (g_free (self->priv->_Name), NULL), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_Name = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->_Name = (g_free (self->priv->_Name), NULL), _tmp1_);
 	g_object_notify ((GObject *) self, "Name");
 }
 
 
 guint dvb_timer_get_Year (DVBTimer* self) {
+	guint result;
 	g_return_val_if_fail (self != NULL, 0U);
-	return self->priv->_Year;
+	result = self->priv->_Year;
+	return result;
 }
 
 
@@ -433,8 +566,10 @@ void dvb_timer_set_Year (DVBTimer* self, guint value) {
 
 
 guint dvb_timer_get_Month (DVBTimer* self) {
+	guint result;
 	g_return_val_if_fail (self != NULL, 0U);
-	return self->priv->_Month;
+	result = self->priv->_Month;
+	return result;
 }
 
 
@@ -446,8 +581,10 @@ void dvb_timer_set_Month (DVBTimer* self, guint value) {
 
 
 guint dvb_timer_get_Day (DVBTimer* self) {
+	guint result;
 	g_return_val_if_fail (self != NULL, 0U);
-	return self->priv->_Day;
+	result = self->priv->_Day;
+	return result;
 }
 
 
@@ -459,8 +596,10 @@ void dvb_timer_set_Day (DVBTimer* self, guint value) {
 
 
 guint dvb_timer_get_Hour (DVBTimer* self) {
+	guint result;
 	g_return_val_if_fail (self != NULL, 0U);
-	return self->priv->_Hour;
+	result = self->priv->_Hour;
+	return result;
 }
 
 
@@ -472,8 +611,10 @@ void dvb_timer_set_Hour (DVBTimer* self, guint value) {
 
 
 guint dvb_timer_get_Minute (DVBTimer* self) {
+	guint result;
 	g_return_val_if_fail (self != NULL, 0U);
-	return self->priv->_Minute;
+	result = self->priv->_Minute;
+	return result;
 }
 
 
@@ -485,8 +626,10 @@ void dvb_timer_set_Minute (DVBTimer* self, guint value) {
 
 
 guint dvb_timer_get_Duration (DVBTimer* self) {
+	guint result;
 	g_return_val_if_fail (self != NULL, 0U);
-	return self->priv->_Duration;
+	result = self->priv->_Duration;
+	return result;
 }
 
 
@@ -497,6 +640,69 @@ void dvb_timer_set_Duration (DVBTimer* self, guint value) {
 }
 
 
+GstElement* dvb_timer_get_sink (DVBTimer* self) {
+	GstElement* result;
+	g_return_val_if_fail (self != NULL, NULL);
+	result = self->priv->_sink;
+	return result;
+}
+
+
+void dvb_timer_set_sink (DVBTimer* self, GstElement* value) {
+	GstElement* _tmp1_;
+	GstElement* _tmp0_;
+	g_return_if_fail (self != NULL);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_sink = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gst_object_ref (_tmp0_)), (self->priv->_sink == NULL) ? NULL : (self->priv->_sink = (gst_object_unref (self->priv->_sink), NULL)), _tmp1_);
+	g_object_notify ((GObject *) self, "sink");
+}
+
+
+static void dvb_timer_class_init (DVBTimerClass * klass) {
+	dvb_timer_parent_class = g_type_class_peek_parent (klass);
+	g_type_class_add_private (klass, sizeof (DVBTimerPrivate));
+	G_OBJECT_CLASS (klass)->get_property = dvb_timer_get_property;
+	G_OBJECT_CLASS (klass)->set_property = dvb_timer_set_property;
+	G_OBJECT_CLASS (klass)->finalize = dvb_timer_finalize;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_ID, g_param_spec_uint ("Id", "Id", "Id", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_CHANNEL, g_param_spec_object ("Channel", "Channel", "Channel", DVB_TYPE_CHANNEL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_NAME, g_param_spec_string ("Name", "Name", "Name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_YEAR, g_param_spec_uint ("Year", "Year", "Year", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_MONTH, g_param_spec_uint ("Month", "Month", "Month", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_DAY, g_param_spec_uint ("Day", "Day", "Day", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_HOUR, g_param_spec_uint ("Hour", "Hour", "Hour", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_MINUTE, g_param_spec_uint ("Minute", "Minute", "Minute", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_DURATION, g_param_spec_uint ("Duration", "Duration", "Duration", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_SINK, g_param_spec_object ("sink", "sink", "sink", GST_TYPE_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+}
+
+
+static void dvb_timer_instance_init (DVBTimer * self) {
+	self->priv = DVB_TIMER_GET_PRIVATE (self);
+}
+
+
+static void dvb_timer_finalize (GObject* obj) {
+	DVBTimer * self;
+	self = DVB_TIMER (obj);
+	(self->priv->_Channel == NULL) ? NULL : (self->priv->_Channel = (g_object_unref (self->priv->_Channel), NULL));
+	self->priv->_Name = (g_free (self->priv->_Name), NULL);
+	(self->priv->_sink == NULL) ? NULL : (self->priv->_sink = (gst_object_unref (self->priv->_sink), NULL));
+	G_OBJECT_CLASS (dvb_timer_parent_class)->finalize (obj);
+}
+
+
+GType dvb_timer_get_type (void) {
+	static GType dvb_timer_type_id = 0;
+	if (dvb_timer_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (DVBTimerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dvb_timer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DVBTimer), 0, (GInstanceInitFunc) dvb_timer_instance_init, NULL };
+		dvb_timer_type_id = g_type_register_static (G_TYPE_OBJECT, "DVBTimer", &g_define_type_info, 0);
+	}
+	return dvb_timer_type_id;
+}
+
+
 static void dvb_timer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	DVBTimer * self;
 	gpointer boxed;
@@ -529,6 +735,9 @@ static void dvb_timer_get_property (GObject * object, guint property_id, GValue
 		case DVB_TIMER_DURATION:
 		g_value_set_uint (value, dvb_timer_get_Duration (self));
 		break;
+		case DVB_TIMER_SINK:
+		g_value_set_object (value, dvb_timer_get_sink (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -567,6 +776,9 @@ static void dvb_timer_set_property (GObject * object, guint property_id, const G
 		case DVB_TIMER_DURATION:
 		dvb_timer_set_Duration (self, g_value_get_uint (value));
 		break;
+		case DVB_TIMER_SINK:
+		dvb_timer_set_sink (self, g_value_get_object (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -574,47 +786,5 @@ static void dvb_timer_set_property (GObject * object, guint property_id, const G
 }
 
 
-static void dvb_timer_class_init (DVBTimerClass * klass) {
-	dvb_timer_parent_class = g_type_class_peek_parent (klass);
-	g_type_class_add_private (klass, sizeof (DVBTimerPrivate));
-	G_OBJECT_CLASS (klass)->get_property = dvb_timer_get_property;
-	G_OBJECT_CLASS (klass)->set_property = dvb_timer_set_property;
-	G_OBJECT_CLASS (klass)->finalize = dvb_timer_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_ID, g_param_spec_uint ("Id", "Id", "Id", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_CHANNEL, g_param_spec_object ("Channel", "Channel", "Channel", DVB_TYPE_CHANNEL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_NAME, g_param_spec_string ("Name", "Name", "Name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_YEAR, g_param_spec_uint ("Year", "Year", "Year", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_MONTH, g_param_spec_uint ("Month", "Month", "Month", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_DAY, g_param_spec_uint ("Day", "Day", "Day", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_HOUR, g_param_spec_uint ("Hour", "Hour", "Hour", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_MINUTE, g_param_spec_uint ("Minute", "Minute", "Minute", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_TIMER_DURATION, g_param_spec_uint ("Duration", "Duration", "Duration", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-}
-
-
-static void dvb_timer_instance_init (DVBTimer * self) {
-	self->priv = DVB_TIMER_GET_PRIVATE (self);
-}
-
-
-static void dvb_timer_finalize (GObject* obj) {
-	DVBTimer * self;
-	self = DVB_TIMER (obj);
-	(self->priv->_Channel == NULL) ? NULL : (self->priv->_Channel = (g_object_unref (self->priv->_Channel), NULL));
-	self->priv->_Name = (g_free (self->priv->_Name), NULL);
-	G_OBJECT_CLASS (dvb_timer_parent_class)->finalize (obj);
-}
-
-
-GType dvb_timer_get_type (void) {
-	static GType dvb_timer_type_id = 0;
-	if (dvb_timer_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (DVBTimerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dvb_timer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DVBTimer), 0, (GInstanceInitFunc) dvb_timer_instance_init, NULL };
-		dvb_timer_type_id = g_type_register_static (G_TYPE_OBJECT, "DVBTimer", &g_define_type_info, 0);
-	}
-	return dvb_timer_type_id;
-}
-
-
 
 
